# US_ITHIM_RShiny2021-07-09.R: ITHIM R code - revised by N Maizlish based on UCD 
# team: N Maizlish/ K Tomari/CJ Jiang /Amy Weiher /J London
# Fixed bug in multiples scenario; updated DFR, lung cancer, mMETs, 

source("./global.R")
library(shiny)
library(ggplot2)

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Webtext is CSV file containing web text content, including titles, kickers,
# and blurb
# Webphotoimage is CSV file containing a the file names in the www folder
# of photos, images and alt text for accessibility
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

webtext <- read.csv(file= "webtext2021-07-09.csv",  head = TRUE, sep = "," , 
                     stringsAsFactors = FALSE)

webfoto <- read.csv(file= "webphotoimage2020-02-04.csv", head = TRUE, 
                    sep = "," , stringsAsFactors = FALSE)

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Geographies files displayed in About>Geographies
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
regions  <- read.csv(file= "regions.csv", head = TRUE, sep = "," , 
                     stringsAsFactors = FALSE)
counties <- read.csv(file= "counties1col.csv", head = TRUE, sep = "," , 
                     stringsAsFactors = FALSE)
# Create region picklist 
geolist <- regions
geolist[31:60,1] <- geolist[1:30,2]
geolist <- geolist[geolist$Region > "", ]
names(geolist)  <- c("Geography", "Type")
geolist[1:5,2]  <- "Region"
geolist[6:35,2] <- "County"
# Get rid of ":"
geolist$Geography <- gsub(":","",geolist$Geography)
geolist[36,1:2] <- c("California","Region")
geolist <- geolist[order(geolist$Type, geolist$Geography),]
geolist[37,1:2] <- c("-------- Counties --------","County")
geolist <- geolist[c(31:37,1:30),]

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Shiny UI
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Placement of favicon

ui <- fluidPage (list(tags$head(HTML('<link rel="icon", href="favicon.ico", 
                  type="image/png" />'))),
             
       theme = "bootstrap2020-04-06.css",

# Skip link for page readers       
 HTML('<div id="skip"><a href="#Introduction">Skip to Main Content</a></div>'), 

# Page title and language for for accessibility requirements
 tags$title("ITHIM USA: Integrated Transport and Health Impact Model"),
 HTML('<html lang="en"></html>'),   
       
# Title is ITHIM Wordmark for website
       titlePanel(windowTitle = "ITHIM USA", 
       div(class ="ithimtitle", 
       div(class = "versiontext",br(),
          HTML(webtext[webtext$Element=="hp.versiontext","Content"])
          ),
          tags$img(src  = webfoto[webfoto$Element == "hp.wordmark","Filename"],
                   alt  = webfoto[webfoto$Element == "hp.wordmark","Alttext"], 
                  title = webfoto[webfoto$Element == "hp.wordmark","Title"])
       ) # End division class ITHIM title
     ), # End Title Panel
       tags$div(id = "top"), 
       tags$style(".fa-arrow-circle-up {color:#0F5A7C}"),
                 
# Navigation bar
navbarPage("", id = 'tabs', position = c("static-top"),
  footer = div(class = "panel-footer", 
   fluidRow(
    column(2, div(class = "lfootercont", 
        h4(tags$b("CONTACT US")),
        h5("(510) 525-4939"), 
        h5(tags$a("neil3971@comcast.net", 
           href  = "mailto:neil3971@comcast.net", 
           style = "color:white;")),br(),
        h5(HTML("Copyright &copy; 2021"),br(),
           "Neil Maizlish"),"Updated July 9, 2021")
     ), 
                   
     column(7, div(class = "footermenu",
       h5(tags$ul(div(class = "lafooter", 
       tags$a(tags$b("HOME"),             href = "#Home"        ), 
       tags$a(tags$b("ABOUT"),            href = "#Introduction"),      
       tags$a(tags$b("RUN ITHIM"),        href = "#RunITHIM"    ),  
       tags$a(tags$b("DECISION SUPPORT"), href = "#Health" ),   
       tags$a(tags$b("USER SUPPORT"),     href = "#UserSupport" )))))
       
     ), # end column,
                    
     column(2, div (class = "footermenu", 
       h5(tags$ul(div(class = "rafooter",   
       tags$a(tags$b("ACCESSIBILITY"),     
           href = "Use_Privacy_Accessibility.pdf"), 
       tags$a(tags$b("PRIVACY POLICY"),    
          href = "Use_Privacy_Accessibility.pdf"),      
       tags$a(tags$b("CONDITIONS OF USE"), 
         href = "Use_Privacy_Accessibility.pdf")))))
     )
      ) # End fluid row
    ),   # End footer 
 
# Home page banner photograph and text message                                     
   tabPanel(h4("Home"), value = "#Home", 
       fluidRow(
           div(class = "phototext" , 
           style = webfoto[webfoto$Element == "hp.banner","Filename"],
           alt   = webfoto[webfoto$Element == "hp.banner","Alttext"], 
#          title = webfoto[webfoto$Element == "hp.banner","Title"],
# Extra height to accomodate large photo size
           style = "height:80vh;"),
           
           div(class = "textboxcenter", 
           div(class = "textboxtext", 
           h1(tags$b(webtext[webtext$Element == "hp.bannertext","Content"])
               )
             )
           ) # End class phototext
        ), # End fluid row banner photo and text message
       
# Home page intro message 
       fluidRow(div(class = "messagebox", 
           div(class = "bannercaption",  
               h1(webtext[webtext$Element  == 
                  "hp.bannercaption", "Content"])), br(),
           div(class = "bannersubcaption", 
               p(webtext[webtext$Element == 
                  "hp.bannersubcaption", "Content"]))) 
           ), # End of fluidRow Intro message

# Home page action buttons    
      fluidRow(div(class = "btn-lg btn-group-lg",
  # Button 1
         column(4,  offset=0,
         actionButton(inputId = "about_tool", style = "height:20em;",
           width = "90%",
           icon  = icon("question", lib = "font-awesome", "fa-3x"),
           style = "background-color:#6194BC", 
           h2(webtext[webtext$Element == "hp.leftbutton", "Content"], 
           style = "font-size:200%;color:white;"), br(),   
           div(class = "borderbox",
           h3(webtext[webtext$Element == "hp.leftsubbutton", "Content"], 
              style = "padding-bottom:10px;"))
            )
          ), 
  # Button 2
          column(4,  
         actionButton(inputId = "use_tool", style = "height:20em;",
           width = "90%",
           icon  = icon("search",lib = "font-awesome","fa-3x"),
           style = "background-color:#0C4B6B", 
           h2(webtext[webtext$Element == "hp.centerbutton", "Content"], 
           style = "font-size:200%;color:white;"), br(),
           div(class = "borderbox",
           h3(webtext[webtext$Element == "hp.centersubbutton","Content"],
              style = "padding-bottom:10px;"))
          )
         ),
  # Button 3
         column(4,
         actionButton(inputId = "go_tool", style = "height:20em;",
           width = "90%",
           icon  = icon("bar-chart-o",lib = "font-awesome", "fa-3x"), 
           style = "background-color:#c4423f", 
           h2(webtext[webtext$Element == "hp.rightbutton", "Content"],  
           style = "font-size:200%;color:white;"), 
           tags$br(), div(class = "borderbox",
           h3(webtext[webtext$Element == "hp.rightsubbutton", "Content"],
              style = "padding-bottom:10px;")))),             
           align = "center") # End class btn-lg btn-group-lg
     
  ),  # End fluidRow action buttons      

# Home page pithy quote
       fluidRow(div(class = "quotebox",  
          p(webtext[webtext$Element == "hp.pithyquote", "Content"]))
          ), # End fluidRow Quotes

# Home page pithy author
       fluidRow(div(class = "pithyauthor", 
        p(webtext[webtext$Element == "hp.pithyquoteauthor","Content"]) 
            ) # end division quotebox
        ), # End fluidRow Quotes

    
# Home page gallery title and images
  
 div(class = "gallerycontainer",
     fluidRow(
      div(class = "gallerytitle", 
         h1(webtext[webtext$Element == "hp.gallerytitle", "Content"])
        ),
    column(3, div(class = "galleryintro", width="100%", 
           p(webtext[webtext$Element == "hp.galleryintro", "Content"]))
      ), #End of Column 3
          
    column(9, 
     fluidRow(div(class = "gpictcontainer",
        column(4, 
        div(class = "figcap", 
            tags$a(HTML(webtext[webtext$Element == 
          "hp.galleryfig1", "Content"]),
        tags$img(src  = webfoto[webfoto$Element == "hp.gallery1","Filename"], 
                alt   = webfoto[webfoto$Element == "hp.gallery1","Alttext"], 
#               title = webfoto[webfoto$Element == "hp.gallery1","Title"],                                       
                     width = "95%"),
                HTML(webtext[webtext$Element == 
                "hp.galleryfigcap1", "Content"])
          ))
       ),
    column(4,
      div(class = "figcap", 
         tags$a(HTML(webtext[webtext$Element == 
                       "hp.galleryfig2", "Content"]),
         tags$img(src   = webfoto[webfoto$Element == "hp.gallery2","Filename"], 
                  alt   = webfoto[webfoto$Element == "hp.gallery2","Alttext"], 
#                 title = webfoto[webfoto$Element == "hp.gallery2","Title"],                                       
                     width = "95%"),
          HTML(webtext[webtext$Element == 
          "hp.galleryfigcap2", "Content"])))
       ),
      column(4,
      div(class = "figcap",     
        tags$a(HTML(webtext[webtext$Element == 
                    "hp.galleryfig3", "Content"]),
         tags$img(src   = webfoto[webfoto$Element == "hp.gallery3","Filename"], 
                  alt   = webfoto[webfoto$Element == "hp.gallery3","Alttext"], 
#                 title = webfoto[webfoto$Element == "hp.gallery3","Title"],                                       
                        width = "95%"),
             HTML(webtext[webtext$Element == 
             "hp.galleryfigcap3", "Content"])))
           )
          ) # end of picture row container
         ), br(),  # End of Fluid Row fo rfirst row of pictures

   fluidRow(div(class = "gpictcontainer",
       column (4,          
       div(class = "figcap", 
        tags$a(HTML(webtext[webtext$Element == 
                              "hp.galleryfig4", "Content"]),
         tags$img(src   = webfoto[webfoto$Element == "hp.gallery4","Filename"], 
                  alt   = webfoto[webfoto$Element == "hp.gallery4","Alttext"], 
 #                title = webfoto[webfoto$Element == "hp.gallery4","Title"],                                       
                  width = "95%"),
        HTML(webtext[webtext$Element == 
        "hp.galleryfigcap4", "Content"])))
    ),
    column (4,
    div(class = "figcap", 
        tags$a(HTML(webtext[webtext$Element == 
                              "hp.galleryfig5", "Content"]),
          tags$img(src   = webfoto[webfoto$Element == "hp.gallery5","Filename"], 
                   alt   = webfoto[webfoto$Element == "hp.gallery5","Alttext"], 
#                  title = webfoto[webfoto$Element == "hp.gallery5","Title"],                                       
                   width = "95%"),
       HTML(webtext[webtext$Element == 
        "hp.galleryfigcap5", "Content"])))
    ),
    column (4,
    div(class = "figcap",     
        tags$a(HTML(webtext[webtext$Element == 
              "hp.galleryfig6", "Content"]),
        tags$img(src   = webfoto[webfoto$Element == "hp.gallery6","Filename"], 
                 alt   = webfoto[webfoto$Element == "hp.gallery6","Alttext"], 
#                title = webfoto[webfoto$Element == "hp.gallery6","Title"],                                       
                       width = "95%"),
            HTML(webtext[webtext$Element == 
            "hp.galleryfigcap6", "Content"]))) 
    ) # end column
       ) # end of picture row container
    ) # End of Fluid Row for second row of pictures
          
       ) # End of column 9
    ), br()  #End of FluidRow 
    ), # End of Gallery Container

# Home page Sponsor
fluidRow(div(class = "sponsorcol", 
  h3("THIS WEBSITE IS SPONSORED BY", style = "color:#6194BC;padding:1em;
     font-weight: bold;"),  
  
 column(3, offset = 2,
   tags$img(src   = webfoto[webfoto$Element == "hp.sponsor","Filename"], 
       alt   = webfoto[webfoto$Element == "hp.sponsor","Alttext"],
       align="right") 
#      title = webfoto[webfoto$Element == "hp.sponsor","Title"])
     ),  #end 1st column
 column(3, style = "padding-top:0px;",
    tags$img(src   = webfoto[webfoto$Element == "hp.sponsor2","Filename"], 
        alt   = webfoto[webfoto$Element == "hp.sponsor2","Alttext"], 
#        align="center") 
       title = webfoto[webfoto$Element == "hp.sponsor2","Title"])
     ), br(),  # End of column 2
 column(2, style = "margin:-30px 0px 40px 0px;",
        tags$img(src   = webfoto[webfoto$Element == "hp.sponsor3","Filename"], 
        alt   = webfoto[webfoto$Element == "hp.sponsor3","Alttext"], 
#        align ="center"), 
        title = webfoto[webfoto$Element == "hp.sponsor3","Title"])
     ) # End column 3
    ) # End div class sponcol
  )  # End fluidRow

# Top of Page Arrow
#    div(tags$a(href="#top", 
#      icon("arrow-circle-up",lib = "font-awesome", "fa-5x")), 
#       align = "right")
            
 ), # end of tab panel Home

# About Page Introduction      
   navbarMenu(h4("About", style = "width:5em;text-align:center"), 
      tabPanel("Introduction",   value = "#Introduction",
       div(class = "phototext", 
           style = webfoto[webfoto$Element == "ap.intro", "Filename"], 
           alt   = webfoto[webfoto$Element == "ap.intro", "Alttext"]
#          title = webfoto[webfoto$Element == "ap.intro", "Title"]
            ),

# Breadcrumbs         
fluidRow (
  column(3, offset =  0, style = "background-color:#d7e4ee;height:144em;", 
         p(tags$ol(div(class = "breadcrumb",
              tags$li(tags$a(href = "#Home", "Home")),
              tags$li("About / Introduction"))
         )),
         
# About Page Menu
 div(class = "apmenu apline apref", HTML(webtext[webtext$Element == "ap.menu", 
                "Content"]), style = "margin-left:25%") 
       
  ), # End of Column

   column(9, offset=0,
       div(class = "apmargin",
         div(class = "aptitle",  h1(webtext[webtext$Element == 
                     "ap.title", "Content"])),br(),
         div(class = "apkicker", h2(webtext[webtext$Element == 
                     "ap.kicker1", "Content"])), br(),
         div(class = "apkickertext", HTML(webtext[webtext$Element == 
                     "ap.kicker1text", "Content"])),br(),
         div(class = "apkicker", h2(webtext[webtext$Element == 
                     "ap.kicker2", "Content"])), br(),
         div(class = "apkickertext", HTML(webtext[webtext$Element == 
                     "ap.kicker2text", "Content"])),br(),
         div(class = "apkicker", h2(webtext[webtext$Element == 
                     "ap.kicker3", "Content"])), br(),
         div(class = "apkickertext", HTML(webtext[webtext$Element == 
                     "ap.kicker3text", "Content"])),br(),
         div(class = "apkicker", h2(webtext[webtext$Element == 
                     "ap.kicker4", "Content"])), br(),
         div(class = "apkickertext", HTML(webtext[webtext$Element == 
                     "ap.kicker4text","Content"])),
# UCD Logo         
#  div(style = "text-align:center",
#  tags$img(src = webfoto[webfoto$Element == "ap.ucdlogo", "Filename"], 
#     alt   = webfoto[webfoto$Element == "ap.ucdlogo", "Alttext"], 
     #              title = webfoto[webfoto$Element == "ap.ucdlogo1", "Title"],                     
#     width = "20%")),
     tags$div(id = "References"),
     div(class = "apkicker", h2(webtext[webtext$Element ==
                  "ap.reftitle", "Content"])), br(),
     div(class = "apreftext", HTML(webtext[webtext$Element == 
                 "ap.references","Content"])),br()                          

       ) #End of margin
     ) # End of column  
  ) # End of fluidRow
# Top of Page arrow
#        div(tags$a(href="#top", icon("arrow-circle-up",
#           lib = "font-awesome", "fa-5x")), align = "right")
       ), # End of tabPanel Introduction

#  About Page Instructions                               
 tabPanel("Instructions", value = "#Instructions", 
  div(class = "phototext" , 
   style = webfoto[webfoto$Element == "ap.instruct", "Filename"], 
   alt   = webfoto[webfoto$Element == "ap.instruct", "Alttext"] 
#  title = webfoto[webfoto$Element == "ap.instruct", "Title"],
  ),  # end division class phototext

# Breadcrumbs         
fluidRow (
  column(3, style = "background-color:#d7e4ee;height:58em;", offset =  0, 
         p(tags$ol(div(class = "breadcrumb",
           tags$li(tags$a(href = "#Home", "Home")),
           tags$li("About / Instructions"))
         )),
         
         # About Page Menu
 div(class = "apmenu apline apref apmenuli", 
     HTML(webtext[webtext$Element == "ap.menu", 
          "Content"]), style = "margin-left:25%")
      ), 
  column(9,
    div(class = "insmargin",
    div(class = "aptitle",  h1(webtext[webtext$Element == 
                                         "in.title", "Content"])),br(),
    div(class = "apkicker", h2(webtext[webtext$Element == 
                                         "in.kicker1", "Content"])), br(),
    div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                          "in.kicker1text", "Content"])),
   

    div(class = "apkickertext",
      column(4, HTML(webtext[webtext$Element == "in.scentext", "Content"])),
      column(4, HTML(webtext[webtext$Element == "in.timetext", "Content"])),
      column(4, HTML(webtext[webtext$Element == "in.geogtext", "Content"])), 
      align = "center"
     ) # end div class
   ),br() # end fluidrow
  )  # End of InsMargin   
) # end fluid row 

# Top of Page arrow   
#        div(tags$a(href="#top", icon("arrow-circle-up",lib = "font-awesome", 
# "fa-5x")), align = "right")
   ), # End of tabPanel Instructions
         
# About Page Scenarios
  tabPanel("Scenarios", value= "#Scenarios",  
     div(class = "phototext", 
         style = webfoto[webfoto$Element == "ap.scenbanner", "Filename"], 
         alt   = webfoto[webfoto$Element == "ap.scenbanner", "Alttext"] 
#        title = webfoto[webfoto$Element == "ap.scenbanner", "Title"]
     ),  
# Breadcrumbs         
fluidRow (
  column(3, style = "background-color:#d7e4ee;height:113em;", offset =  0, 
         p(tags$ol(div(class = "breadcrumb",
          tags$li(tags$a(href = "#Home", "Home")),
          tags$li("About / Scenarios"))
         )),
         
# About Page Menu
div(class = "apmenu apline apref", HTML(webtext[webtext$Element == "ap.menu", 
                     "Content"]), style = "margin-left:25%")
  ), 
  column(8,
      div(class = "scenmargin",
      div(class = "aptitle", h1(webtext[webtext$Element == 
                  "sc.title", "Content"])),br(),
      div(class = "apkicker", h2(webtext[webtext$Element == 
                   "sc.kicker1", "Content"])), br(),
      div(class = "scenkickertext", HTML(webtext[webtext$Element == 
                  "sc.kicker1text", "Content"])), br()
       ), # End scenario margin

# Baseline      
     fluidRow(    
       column(2, offset=1, 
         tags$img(src = webfoto[webfoto$Element == "ap.scenario1", "Filename"], 
                alt   = webfoto[webfoto$Element == "ap.scenario1", "Alttext"], 
 #              title = webfoto[webfoto$Element == "ap.scenario1", "Title"],                     
                  width = "50%"), 
         align = "right"),
       column(8,
              div(class = "scentitle", h4(HTML(webtext[webtext$Element == 
                           "sc.scen0title", "Content"]))), 
              div(class = "scentext",  HTML(webtext[webtext$Element == 
                   "sc.scen0text", "Content"]))
       ) #end column
     ), hr(),  #End fluid row

# CARB 2030  
#      fluidRow(    
#       column(2, offset=1, 
#        tags$img(src = webfoto[webfoto$Element == "ap.scenario2", "Filename"], 
#                 alt = webfoto[webfoto$Element == "ap.scenario2", "Alttext"], 
#             title = webfoto[webfoto$Element == "ap.scenario2", "Title"],         
#                    width = "50%"), 
#           align = "right"),
#         column(8,
#           div(class = "scentitle", h4(HTML(webtext[webtext$Element == 
#                       "sc.scen1title", "Content"]))), 
#           div(class = "scentext",  HTML(webtext[webtext$Element == 
#                        "sc.scen1text", "Content"]))
#           ) #end column
#          ), hr(),  #End fluid row

# CSMP 2020  
#     fluidRow(    
#       column(2, offset=1, br(),
#        tags$img(src = webfoto[webfoto$Element == "ap.scenario3", "Filename"], 
#                alt  = webfoto[webfoto$Element == "ap.scenario3", "Alttext"], 
#              title = webfoto[webfoto$Element == "ap.scenario3", "Title"],         
#                width = "50%"), 
#                align = "right"),
#       column(8,
#          div(class = "scentitle", h4(HTML(webtext[webtext$Element == 
#                      "sc.scen2title", "Content"]))), 
#          div(class = "scentext",  HTML(webtext[webtext$Element == 
#                     "sc.scen2text", "Content"]))
#         ) #end column
#        ), hr(), #End fluid row 

# SCS2040 
#     fluidRow(    
#       column(2, offset=1, br(), 
#       tags$img(src = webfoto[webfoto$Element == "ap.scenario4", "Filename"], 
#              alt   = webfoto[webfoto$Element == "ap.scenario4", "Alttext"], 
#             title = webfoto[webfoto$Element == "ap.scenario4", "Title"],         
#              width = "50%"), 
#              align = "right"),
#       column(8,
#         div(class = "scentitle", h4(webtext[webtext$Element == 
#                     "sc.scen3title", "Content"])), 
#         div(class = "scentext",  HTML(webtext[webtext$Element == 
#                       "sc.scen3text", "Content"]))
#          ) #end column
#         ), hr(), # End fluid row 

# SCS2040 
     fluidRow(    
      column(2, offset=1, br(), 
         tags$img(src = webfoto[webfoto$Element == "ap.scenario5", "Filename"], 
                alt  = webfoto[webfoto$Element == "ap.scenario5", "Alttext"], 
#              title = webfoto[webfoto$Element == "ap.scenario5", "Title"],         
                   width = "50%"), 
          align = "right"),
        column(8,
           div(class = "scentitle", h4(HTML(webtext[webtext$Element == 
                       "sc.scen4title", "Content"]))), 
           div(class = "scentext", HTML(webtext[webtext$Element == 
                       "sc.scen4text", "Content"]))
           ) #end column
         ), hr(),  # End fluid row 
    fluidRow(    
      column(2, offset=1, br(), 
       tags$img(src  = webfoto[webfoto$Element == "ap.scenario6", "Filename"], 
                alt   = webfoto[webfoto$Element == "ap.scenario6", "Alttext"], 
#               title = webfoto[webfoto$Element == "ap.scenario6", "Title"],         
                width = "50%"), 
                align = "right"),
        column(8,
           div(class = "scentitle", h4(webtext[webtext$Element == 
                       "sc.scen5title", "Content"])), 
           div(class = "scentext", HTML(webtext[webtext$Element == 
                       "sc.scen5text", "Content"]))
           ) #end column
         ), hr(), # End fluid row
  fluidRow(    
    column(2, offset=1, br(), 
      tags$img(src   = webfoto[webfoto$Element == "ap.scenario7", "Filename"], 
               alt   = webfoto[webfoto$Element == "ap.scenario7", "Alttext"], 
#              title = webfoto[webfoto$Element == "ap.scenario7", "Title"],         
               width = "50%"), 
               align = "right"),
        column(8,
           div(class = "scentitle", h4(webtext[webtext$Element == 
                       "sc.scen6title", "Content"])), 
           div(class = "scentext", HTML(webtext[webtext$Element == 
                       "sc.scen6text", "Content"]))
           ) #end column
          ), hr(), # End fluid row
  fluidRow(    
    column(2, offset=1, br(), 
        tags$img(src   = webfoto[webfoto$Element == "ap.scenario8", "Filename"], 
                 alt   = webfoto[webfoto$Element == "ap.scenario8", "Alttext"], 
#                title = webfoto[webfoto$Element == "ap.scenario8", "Title"],         
                 width = "50%"), 
                 align = "right"),
        column(8,
           div(class = "scentitle", h4(webtext[webtext$Element == 
                       "sc.scen7title", "Content"])), 
           div(class = "scentext", HTML(webtext[webtext$Element == 
                       "sc.scen7text", "Content"]))
        ) #end column
      ), hr(), # End fluid row
  fluidRow(    
     column(2, offset=1, br(), 
       tags$img(src   = webfoto[webfoto$Element == "ap.scenario9", "Filename"], 
            alt   = webfoto[webfoto$Element == "ap.scenario9", "Alttext"], 
#           title = webfoto[webfoto$Element == "ap.scenario9", "Title"],         
            width = "50%"), 
            align = "right"),
     column(8,
        div(class = "scentitle", h4(webtext[webtext$Element == 
                    "sc.scen8title", "Content"])), 
        div(class = "scentext", HTML(webtext[webtext$Element == 
                    "sc.scen8text", "Content"]))
        ) #end column
      ), hr(), # End fluid row
  fluidRow(    
    column(2, offset=1, br(), 
      tags$img(src  = webfoto[webfoto$Element == "ap.scenario10", "Filename"], 
              alt   = webfoto[webfoto$Element == "ap.scenario10", "Alttext"], 
#             title = webfoto[webfoto$Element == "ap.scenario10", "Title"],         
              width = "50%"), 
      align = "right"),
     column(8,
           div(class = "scentitle", h4(webtext[webtext$Element == 
                       "sc.scen9title", "Content"])), 
           div(class = "scentext", HTML(webtext[webtext$Element == 
                       "sc.scen9text", "Content"])),br(),br()
            ) #end column
         ) #End of FluidRow
  ) #end column
) #End of FluidRow

      # Top of Page arrow   
#      div(tags$a(href="#top", 
#          icon("arrow-circle-up",lib = "font-awesome", "fa-5x")), 
#          align = "right")
    ), # End of tabPanel Scenarios
                        
                        
# tabPanel("Geographies", value= "#Geographies", 
#    div(class = "phototext", 
#       style = webfoto[webfoto$Element == "ap.geobanner", "Filename"], 
#       alt   = webfoto[webfoto$Element == "ap.geobanner", "Alttext"] 
#      title = webfoto[webfoto$Element == "ap.geobanner", "Title"]
#       ),  

# Breadcrumbs         
#fluidRow (
# column(3, style = "background-color:#d7e4ee;height:85em;", offset =  0, 
#        p(tags$ol(div(class = "breadcrumb",
#         tags$li(tags$a(href = "#Home", "Home")),
#         tags$li("About / Geographies"))
#        )),
#        
# About Page Menu
# div(class = "apmenu apline apref", HTML(webtext[webtext$Element == "ap.menu", 
#     "Content"]), style = "margin-left:25%")
# ),
#     column(9,
# div(class = "apmargin",
# div(class = "aptitle", h1(webtext[webtext$Element == "geo.title", 
#  "Content"])), br(),
#div(class = "apkicker", h2(webtext[webtext$Element == "geo.kicker1", 
#  "Content"])), br(),
#div(class = "apkickertext", HTML(webtext[webtext$Element == 
#   "geo.kicker1text", "Content"])),br(),
#fluidRow(div(class = "geotables",
#         column(5, tableOutput("regions"), style = "margin-left:10em;"),
#         column(3, tableOutput("counties"))
#   )
#      ) #end of FluidRow
#   ) # end of reduced margins
#      ) # end col
# ) # End fluidRow
  
 # Top of page arrow 
 #  div(tags$a(href="#top", 
 #      icon("arrow-circle-up", lib = "font-awesome", "fa-5x")), 
 #      align = "right")
 #  ),  # End of Geographies Tab panel 
        
                        
# Time Periods About Page                        
 tabPanel("Time Periods",   value= "#TimePeriods", 
    div(class = "phototext", 
     style = webfoto[webfoto$Element == "ap.timebanner", "Filename"], 
      alt  = webfoto[webfoto$Element == "ap.timebanner", "Alttext"] 
#    title = webfoto[webfoto$Element == "ap.timebanner", "Title"]),
       ),

# Breadcrumbs         
fluidRow (
  column(3, style = "background-color:#d7e4ee;height:40em;", offset =  0, 
         p(tags$ol(div(class = "breadcrumb",
                   tags$li(tags$a(href = "#Home", "Home")),
                   tags$li("About / Time Periods"))
         )),
         
# About Page Menu
  div(class = "apmenu apline apref", HTML(webtext[webtext$Element == "ap.menu", 
                      "Content"]), style = "margin-left:25%")
  ),
  column(9,
   div(class = "apmargin",        
      div(class = "aptitle", h1(webtext[webtext$Element == 
                  "tm.title", "Content"])),br(),
      div(class = "apkicker", h2(webtext[webtext$Element == 
                  "tm.kicker1", "Content"])), br(),
      div(class = "apkickertext",HTML(webtext[webtext$Element == 
                  "tm.kicker1text", "Content"])),
      div(class = "apkickertext",HTML(webtext[webtext$Element == 
                   "tm.kicker2text", "Content"]), style = "margin-left:40%;")
    )  # end of reduced margins
  ) #end of Column
) # End of fluidRow
   
   
 # Top of page arrow 
 #      div(tags$a(href="#top", 
 #         icon("arrow-circle-up",lib = "font-awesome", "fa-5x")), 
 #         align = "right")
                            
  ), # End of Time Periods Panel

# TAb Panel Methods
tabPanel("Methods", value= "#Methods",  
 div(class = "phototext",
   style = webfoto[webfoto$Element == "ap.methodsbanner", "Filename"], 
   alt   = webfoto[webfoto$Element == "ap.methodsbanner", "Alttext"] 
#   title = webfoto[webfoto$Element == "ap.methodsbanner", "Title"]
    ), 

# Breadcrumbs         
fluidRow (
  column(3, style = "background-color:#d7e4ee;height:340em;", offset =  0, 
         p(tags$ol(div(class = "breadcrumb",
                       tags$li(tags$a(href = "#Home", "Home")),
                       tags$li("About / Methods"))
         )),
         
# About Page Menu
 div(class = "apmenu apline apref", HTML(webtext[webtext$Element == "ap.menu", 
                      "Content"]), style = "margin-left:25%")
  ),
  column(9,
      div(class = "apmargin",                              
      div(class = "aptitle",      h1(webtext[webtext$Element == 
                  "me.title", "Content"])), br(),
      div(class = "apkicker",     h2(webtext[webtext$Element == 
                  "me.kicker1", "Content"])), br(),
      div(class = "apsubkicker",  h3(webtext[webtext$Element == 
                  "me.subkicker1", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                  "me.kicker1text", "Content"])),br(),
      div(class = "apsubkicker",  h3(webtext[webtext$Element == 
                  "me.subkicker2", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                  "me.kicker2text", "Content"])),br(),
      div(class = "apkicker",     h2(webtext[webtext$Element ==
                  "me.kicker2", "Content"])), br(),
      div(class = "apsubkicker",  h3(webtext[webtext$Element == 
                  "me.subkicker3", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                  "me.subkicker3text", "Content"])),br(),
      div(class = "apsubkicker",  h3(webtext[webtext$Element == 
                  "me.subkicker4", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                  "me.subkicker4text", "Content"])),br(),
      div(class = "apsubkicker",  h3(webtext[webtext$Element == 
                  "me.subkicker5","Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                  "me.subkicker5text", "Content"])),br(),
      div(class = "apsubkicker",  h3(webtext[webtext$Element == 
                  "me.subkicker6", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                  "me.subkicker6text", "Content"])),br(),
      div(class = "apkicker",     h2(webtext[webtext$Element == 
                  "me.kicker3","Content"])), br(),
      div(class = "apsubkicker",  h3(webtext[webtext$Element == 
                  "me.subkicker7", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                  "me.subkicker7text", "Content"])),br(),
      div(class = "apsubkicker",  h3(webtext[webtext$Element == 
                  "me.subkicker8", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                  "me.subkicker8text", "Content"])), br(),
      div(class = "apsubkicker",  h3(webtext[webtext$Element ==
                  "me.subkicker9", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element ==
                   "me.subkicker9text","Content"])), br(),
      div(class = "apsubkicker",  h3(webtext[webtext$Element == 
                  "me.subkicker10", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                  "me.subkicker10text", "Content"])), br(),
      div(class = "apsubkicker",  h3(webtext[webtext$Element == 
                  "me.subkicker11","Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                  "me.subkicker11text", "Content"])), br(),
      div(class = "apsubkicker",  h3(webtext[webtext$Element == 
                  "me.subkicker12", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                  "me.subkicker12text", "Content"])), br(),
      div(class = "apkicker",  h2(webtext[webtext$Element == 
                  "me.reftitle", "Content"])), br(),
                   tags$div(id = "ReferencesMethods"),
            div(class = "apreftext", HTML(webtext[webtext$Element == 
                  "me.references", "Content"])), br(),
      #                  tags$div(id = "ReferencesMethods"),
      HTML(webtext[webtext$Element == 
                   "me.photocredits", "Content"]), br()
      
      
    )  # end of reduced margins
  ) #End of Column
) # End of fluidRow

# Top of Page
#          div(tags$a(href = "#top", icon("arrow-circle-up",
#          lib = "font-awesome", "fa-5x")), align = "right")
                                 
  ) # End of Time Methods Panel
),  # End of About NavBarMenu Panel
        
# Run ITHIM Page
tabPanel(h4("Run ITHIM"), value = "#RunITHIM",
   div(class = "phototext", 
       style = webfoto[webfoto$Element == "rp.banner", "Filename"], 
       alt   = webfoto[webfoto$Element == "rp.banner", "Alttext"] 
#      title = webfoto[webfoto$Element == "rp.banner", "Title"]) 
       ),
   
# Breadcrumbs
   p(tags$ol(div(class = "breadcrumb", style = "background-color:white;",
                 tags$li(tags$a(href = "#Home", "Home")),
                 tags$li("Run ITHIM"))
   )),
   
   div(class = "rpmargin",                              
       div(class = "aptitle", h1(webtext[webtext$Element == 
                     "rp.title", "Content"])), br(),
       div(class = "apkicker",  h2(webtext[webtext$Element == 
                     "rp.kicker1", "Content"])), br(),
       div(class = "scenkickertext",  HTML(webtext[webtext$Element == 
                   "rp.kicker1text", "Content"])), br()
   ), # End margin container

    ithim_toolUI("TOOL")
   ),
  # EndRun ITHIM Tab Panel
   
# Feedback Page
# tabPanel(h4("Feedback"), value = "#Feedback",
#   div(class = "phototext", 
#       style = webfoto[webfoto$Element == "fp.banner", "Filename"], 
#       alt   = webfoto[webfoto$Element == "fp.banner", "Alttext"] 
#      title = webfoto[webfoto$Element == "fp.banner", "Title"])
#     ),
#  
#    p(HTML('<ol class = "breadcrumb">
#   <li><a href = "#Home" >Home</a></li>
#         <li>Feedback</li>
#         </ol>')),
#  div(class = "apmargin",
#      div(class = "aptitle", h1(webtext[webtext$Element == "fp.title", 
#                   "Content"])), br(),
#      div(class = "apkicker", h2(webtext[webtext$Element == "fp.kicker1", 
#                   "Content"])), br(),
#      div(class = "apkickertext", HTML(webtext[webtext$Element == 
#                   "fp.kicker1text", "Content"])),br(),         
#      div(class = "apsubkicker",  h3(webtext[webtext$Element == 
#                    "fp.subkicker1", "Content"])), 
#     div(class = "apkickertext", HTML(webtext[webtext$Element == 
#                  "fp.subkicker1text", "Content"])),br(),
#     div(class = "apsubkicker",  h3(webtext[webtext$Element == 
#                  "fp.subkicker2", "Content"])), 
#     div(class = "apkickertext", HTML(webtext[webtext$Element == 
#                  "fp.subkicker2text", "Content"])),br(),
#     div(class = "apsubkicker",  h3(webtext[webtext$Element == 
#                   "fp.subkicker3", "Content"])), 
#    div(class = "apkickertext", HTML(webtext[webtext$Element == 
#                    "fp.subkicker3text", "Content"])),br(),
#      div(class = "apsubkicker",  h3(webtext[webtext$Element == 
#                    "fp.subkicker4", "Content"])), 
#      div(class = "apkickertext", HTML(webtext[webtext$Element == 
#                  "fp.subkicker4text", "Content"])),br(),
#      div(class = "apsubkicker",  h3(webtext[webtext$Element == 
#                    "fp.subkicker5", "Content"])), 
#      div(class = "apkickertext", HTML(webtext[webtext$Element == 
#                     "fp.subkicker5text", "Content"])),br(),
#     div(class = "apsubkicker",  h3(webtext[webtext$Element == 
#                   "fp.subkicker6", "Content"])), 
#     div(class = "apkickertext", HTML(webtext[webtext$Element == 
#                  "fp.subkicker6text", "Content"])),br(), 
#     div(class = "apsubkicker",  h3(webtext[webtext$Element == 
#                   "fp.subkicker7", "Content"])), 
#     div(class = "apkickertext", HTML(webtext[webtext$Element == 
#                  "fp.subkicker7text", "Content"])),br(),
#     div(class = "apsubkicker",  h3(webtext[webtext$Element == 
#                  "fp.subkicker8", "Content"])), 
#     div(class = "apkickertext", HTML(webtext[webtext$Element == 
#                  "fp.subkicker8text", "Content"])),br(),
#     div(class = "apsubkicker",  h3(webtext[webtext$Element == 
#                                             "fp.subkicker9", "Content"])), 
#     div(class = "apkickertext", HTML(webtext[webtext$Element == 
#                    "fp.subkicker9text", "Content"])),br() 
#    )  # apmargin end   

# Top of page arrow     
#  div(tags$a(href="#top", 
#  icon("arrow-circle-up",lib = "font-awesome", "fa-5x")), align = "right")

# ), # Tab panel end

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# DS: health
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

navbarMenu(h4("Decision Support", style = "width:9em;text-align:center"), 
 tabPanel("Health Outcomes",  value  = "#Health",
   div(class = "phototext", 
       style = webfoto[webfoto$Element == "ds.ho.banner", "Filename"], 
       alt   = webfoto[webfoto$Element == "ds.ho.banner", "Alttext"] 
#      title = webfoto[webfoto$Element == "ds.ho.banner", "Title"]
   ),

# Breadcrumbs         
   fluidRow (
    column(3, style = "background-color:#d7e4ee;height:260em;", offset =  0, 
       p(tags$ol(div(class = "breadcrumb",
         tags$li(tags$a(href = "#Home", "Home")),
         tags$li("Decision Support / Health Outcomes") 
         ), style="font-size:75%;"
       )),
       
# About Page Menu
       div(class = "apmenu apline apref", 
           HTML(webtext[webtext$Element == "ds.menu", 
                "Content"]), style = "margin-left:25%")
            ), 
         
# Health Outcomes Page Title
     
  column(9,  
     div(class = "apmargin", 
     div(class = "aptitle", h1(webtext[webtext$Element == 
                               "ds.ho.title", "Content"])), br(),
     div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                  "ds.ho.kicker1text", "Content"])),
     div(class = "apkicker", h2(webtext[webtext$Element == 
                                 "ds.ho.patitle", "Content"])),
     div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                      "ds.ho.pakicker1text", "Content"])),
     div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.ho.pakicker2text", "Content"])),
     div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                        "ds.ho.pakicker3text", "Content"])),
     div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                        "ds.ho.pakicker4text", "Content"])),
     div(class = "apkicker", h2(webtext[webtext$Element == 
                                        "ds.ho.rtititle", "Content"])),
     div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                        "ds.ho.rtikicker1text", "Content"])),
     div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                        "ds.ho.rtikicker2text", "Content"])),
     div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                        "ds.ho.rtikicker3text", "Content"])),
     
     div(class = "apkicker", h2(webtext[webtext$Element == 
                                        "ds.ho.pm25title", "Content"])),
     div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.ho.pm25kicker1text", "Content"])),
     div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.ho.pm25kicker2text", "Content"])),
     div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.ho.pm25kicker3text", "Content"])),
     div(class = "apsubkicker", h3(webtext[webtext$Element == 
                                         "ds.ho.pm25subkicker", "Content"])),
     div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                    "ds.ho.pm25subkicker1text", "Content"])),
     div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                    "ds.ho.pm25subkicker2text", "Content"])),
     
     div(class = "apkicker", h2(webtext[webtext$Element == 
                                            "ds.ho.noisetitle", "Content"])),
     div(class = "apkickertext", HTML(webtext[webtext$Element ==
                                      "ds.ho.noisekicker1text", "Content"])),
     tags$div(id = "ReferencesHealth"),
     div(class = "apkicker",  h2(webtext[webtext$Element == 
                              "ds.ho.reftitle", "Content"])), br(),
     div(class = "apreftext", HTML(webtext[webtext$Element == 
                   "ds.ho.references", "Content"])), br()
 
       ) # End Column
      ) # End FluidRow 
    ) # End of margin
  
   
  ), #End tab Panel

 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 # DS: Strategies
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 # Strategies
 
tabPanel(HTML("Strategies<br>&nbsp;&nbsp;&nbsp;&nbsp; Introduction"), 
    value  = "#IntroStrategies",
    div(class = "phototext", 
        style = webfoto[webfoto$Element == "ds.in.banner", "Filename"], 
        alt   = webfoto[webfoto$Element == "ds.in.banner", "Alttext"]
#       title = webfoto[webfoto$Element == "ds.in.banner", "Title"]
    ),
    
# Breadcrumbs         
  fluidRow (
   column(3, style = "background-color:#d7e4ee;height:40em;", offset =  0, 
     p(tags$ol(div(class = "breadcrumb", 
     tags$li(tags$a(href = "#Home", "Home")),
     tags$li("Decision Support / Strategies / Introduction") 
     ), style="font-size:75%;"
     )),
             
# Decision Support Menu
   div(class = "apmenu apline apref", HTML(webtext[webtext$Element == 
                "ds.menu", "Content"]), style = "margin-left:25%")
        ), 
    column(9,  
     div(class = "apmargin", 
         div(class = "aptitle", h1(webtext[webtext$Element == 
                                           "ds.st.title","Content"])),br(),
         div(class = "apkickertext", HTML(webtext[webtext$Element ==
                                           "ds.st.kicker1text","Content"]))
      ) # End of division  
    ) # End of column  
 ) # End of fluidRow                  
     ), #End tab Panel

# Physical Activity

tabPanel(HTML("&nbsp;&nbsp;&nbsp;&nbsp;Physical Activity"),  
         value  = "#PhysicalActivity",
  div(class = "phototext", 
          style = webfoto[webfoto$Element == "ds.pa.banner", "Filename"], 
          alt   = webfoto[webfoto$Element == "ds.pa.banner", "Alttext"] 
#         title = webfoto[webfoto$Element == "ds.pa.banner", "Title"]
      ),

# Breadcrumbs         
 fluidRow (
  column(3, style = "background-color:#d7e4ee;height:200em;", offset =  0, 
    p(tags$ol(div(class = "breadcrumb",
     tags$li(tags$a(href = "#Home", "Home")),
     tags$li("Decision Support / Strategies / Physical Activity") 
     ), style="font-size:75%;"
 )),
 
# Decision Support Menu
  div(class = "apmenu apline apref", HTML(webtext[webtext$Element == "ds.menu", 
               "Content"]), style = "margin-left:25%")
    ), 
   column(9,  
  div(class = "apmargin", 
      div(class = "aptitle",    h1(webtext[webtext$Element == 
                                 "ds.st.patitle", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                  "ds.st.pa1text", "Content"])),
      div(class = "apkicker", h2(webtext[webtext$Element == 
                                 "ds.st.pakicker1", "Content"])),
      div(class = "apsubkicker", h3(webtext[webtext$Element == 
                                    "ds.st.pasubkicker1", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.st.pasubkicker1text", "Content"])),
      div(class = "apsubkicker", h3(webtext[webtext$Element == 
                                     "ds.st.pasubkicker2", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.st.pasubkicker2text", "Content"])),
      div(class = "apsubkicker", h3(webtext[webtext$Element == 
                                    "ds.st.pasubkicker3", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.st.pasubkicker3text1", "Content"])),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.st.pasubkicker3text2", "Content"])),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.st.pasubkicker3text3", "Content"])),
      div(class = "apkicker", h2(webtext[webtext$Element == 
                                        "ds.st.pakicker2", "Content"])),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                        "ds.st.pakicker2text", "Content"])),
      div(class = "apsubkicker", h3(webtext[webtext$Element == 
                                    "ds.st.pasubkicker4", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.st.pasubkicker4text", "Content"])),
      div(class = "apsubkicker", h3(webtext[webtext$Element == 
                                     "ds.st.pasubkicker5", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                        "ds.st.pasubkicker5text", "Content"])),
      div(class = "apsubkicker", h3(webtext[webtext$Element == 
                                    "ds.st.pasubkicker6","Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                        "ds.st.pasubkicker6text", "Content"])),
      div(class = "apsubkicker", h3(webtext[webtext$Element == 
                                     "ds.st.pasubkicker7","Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.st.pasubkicker7text", "Content"]))
      ) # End of division  
     ) # End of column  
    ) # End of fluidRow                  
         
), #End tab Panel

# Safety
tabPanel(HTML("&nbsp;&nbsp;&nbsp;&nbsp;Safety"),  value = "#Safety",
 div(class = "phototext", 
    style = webfoto[webfoto$Element == "ds.rti.banner", "Filename"], 
    alt   = webfoto[webfoto$Element == "ds.rti.banner", "Alttext"] 
#   title = webfoto[webfoto$Element == "ds.rti.banner", "Title"]
   ),

# Breadcrumbs         
 fluidRow (
   column(3, style = "background-color:#d7e4ee;height:310em;", offset =  0, 
          p(tags$ol(div(class = "breadcrumb",
            tags$li(tags$a(href = "#Home", "Home")),
            tags$li("Decision Support / Strategies/ Increase Safety") 
            ), style="font-size:75%;"
          )),
          
# Decision Support Menu
  div(class = "apmenu apline apref", HTML(webtext[webtext$Element == "ds.menu", 
      "Content"]), style = "margin-left:25%")
        ), 
  column(9,  
     div(class = "apmargin", 
       div(class = "aptitle", h1(webtext[webtext$Element == 
                                  "ds.st.rtititle","Content"])), br(),
       div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                        "ds.st.rti","Content"])),
       div(class = "apsubkicker", h3(webtext[webtext$Element == 
                                     "ds.st.rtisubkicker1", "Content"])), br(),
       div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                 "ds.st.rtisubkicker1text", "Content"])), br(),
       div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                 "ds.st.rtisubkicker2text", "Content"])), br(),
       div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                 "ds.st.rtisubkicker3text", "Content"])), br(),
       div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                 "ds.st.rtisubkicker4text", "Content"])), br(),
       div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                 "ds.st.rtisubkicker5text", "Content"])), br(),
       div(class = "apsubkicker", h3(webtext[webtext$Element == 
                                     "ds.st.rtisubkicker2", "Content"])), br(),
       div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                 "ds.st.rtisubkicker6text", "Content"])), br(),
       div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                 "ds.st.rtisubkicker7text", "Content"])), br(),
       div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                 "ds.st.rtisubkicker8text", "Content"])), br(),
       div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                 "ds.st.rtisubkicker9text", "Content"])), br(),
       div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                "ds.st.rtisubkicker10text", "Content"])), br(),
       div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                "ds.st.rtisubkicker11text", "Content"])), br(),
       div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                "ds.st.rtisubkicker12text", "Content"])), br(),
       div(class = "apsubkicker", h3(webtext[webtext$Element == 
                                     "ds.st.rtisubkicker3", "Content"])), br(),
       div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                "ds.st.rtisubkicker13text", "Content"])), br(),
              
# References
      tags$div(id = "ReferencesSafety"),
      div(class = "apkicker",  h2(webtext[webtext$Element == 
          "ds.st.rtireftitle", "Content"])), br(),
      div(class = "apreftext", HTML(webtext[webtext$Element == 
           "ds.st.rtireferences", "Content"])), br()
 
              
      ) # End of division margins 
   ) # End of column  
 ) # End of fluidRow                
), #End of Tab Panel

# Air Pollution
tabPanel(HTML("&nbsp;&nbsp;&nbsp;&nbsp;Air Pollution"),  
    value  = "#AirPollution",
    div(class = "phototext", 
        style = webfoto[webfoto$Element == "ds.pm.banner", "Filename"], 
        alt   = webfoto[webfoto$Element == "ds.pm.banner", "Alttext"] 
#       title = webfoto[webfoto$Element == "ds.pm.banner", "Title"]
            ),
# Breadcrumbs         
 fluidRow (
   column(3, style = "background-color:#d7e4ee;height:100em;", offset =  0, 
          p(tags$ol(div(class = "breadcrumb",
             tags$li(tags$a(href = "#Home", "Home")),
             tags$li("Decision Support / Strategies/ Air Pollution") 
             ), style="font-size:75%;"
          )),
          
# Decision Support Menu
   div(class = "apmenu apline apref", HTML(webtext[webtext$Element == "ds.menu", 
    "Content"]), style = "margin-left:25%")
           ), 
    column(9,  
     div(class = "apmargin", 
       div(class = "aptitle", h1(webtext[webtext$Element == 
                                           "ds.st.pmtitle", "Content"])), br(),
       div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                                    "ds.st.pm25", "Content"])),
       div(class = "apsubkicker", h3(webtext[webtext$Element == 
                                    "ds.st.pm25subkicker1", "Content"])), br(),
       div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                      "ds.st.pm25subkicker1text", "Content"])),
       div(class = "apsubkicker", h3(webtext[webtext$Element == 
                                    "ds.st.pm25subkicker2", "Content"])), br(),
       div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                      "ds.st.pm25subkicker2text", "Content"])),
       div(class = "apsubkicker", h3(webtext[webtext$Element == 
                                    "ds.st.pm25subkicker3", "Content"])), br(),
       div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                      "ds.st.pm25subkicker3text", "Content"])),
# References
  div(class = "apkicker",  h2(webtext[webtext$Element == 
                "ds.st.pm25reftitle", "Content"])), br(),
  div(class = "apreftext", HTML(webtext[webtext$Element == 
                "ds.st.pm25references", "Content"])), br(),
  tags$div(id = "ReferencesPM25")

             ) # End of division  
           ) # End of column  
         ) # End of fluidRow      
       ), #End of Tab Panel      

# Evidence         
  tabPanel("Evidence",  value  = "#Evidence",
     div(class = "phototext", 
         style = webfoto[webfoto$Element == "ds.ev.banner", "Filename"], 
         alt   = webfoto[webfoto$Element == "ds.ev.banner", "Alttext"] 
#        title = webfoto[webfoto$Element == "ds.ev.banner", "Title"]
     ),
# Breadcrumbs         
 fluidRow (
   column(3, style = "background-color:#d7e4ee;height:275em;", offset =  0, 
          p(tags$ol(div(class = "breadcrumb",
             tags$li(tags$a(href = "#Home", "Home")),
             tags$li("Decision Support / Evidence")),
             style="font-size:75%;")
          ),
          
# About Page Menu
  div(class = "apmenu apline apref", HTML(webtext[webtext$Element == "ds.menu", 
      "Content"]), style = "margin-left:25%")
           ), 
   column(9,  
      div(class = "apmargin", 
      div(class = "aptitle", h1(webtext[webtext$Element == 
                                 "ds.ev.title", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.ev.introtext", "Content"])),
      div(class = "apkicker", h2(webtext[webtext$Element == 
                                         "ds.ev.kicker1","Content"])),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.ev.kicker1text", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.ev.kicker2text", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.ev.kicker3text", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.ev.kicker4text", "Content"])), br(),
      div(class = "apkicker", h2(webtext[webtext$Element == 
                                           "ds.ev.kicker2", "Content"])),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.ev.kicker5text", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.ev.kicker6text", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.ev.kicker7text", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.ev.kicker8text", "Content"])), br(),
      div(class = "apkicker", h2(webtext[webtext$Element == 
                                           "ds.ev.kicker3", "Content"])),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.ev.kicker9text", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                      "ds.ev.kicker10text", "Content"])), br(),
              
# References
       tags$div(id = "ReferencesEvidence"),  
       div(class = "apkicker",  h2(webtext[webtext$Element == 
                                   "ds.ev.reftitle", "Content"])), br(),
       div(class = "apreftext", HTML(webtext[webtext$Element == 
                                 "ds.ev.references", "Content"])), br()
     ) # End of division  
   ) # End of column  
  ) # End of fluidRow      
), #End of Tab Panel    


# Data & Resources Page ),
tabPanel("Data & Resources", value = "#Data",
     div(class = "phototext", 
         style = webfoto[webfoto$Element == "ds.dr.banner", "Filename"], 
         alt   = webfoto[webfoto$Element == "ds.dr.banner", "Alttext"] 
#        title = webfoto[webfoto$Element == "ds.dr.banner", "Title"]
     ),

# Breadcrumbs         
 fluidRow (
  column(3, style = "background-color:#d7e4ee;height:230em;", offset =  0, 
   p(tags$ol(div(class = "breadcrumb",
     tags$li(tags$a(href = "#Home", "Home")),
     tags$li("Decision Support / Data & Resources"),
     style="font-size:75%;"))
     ), 
     
# About Page Menu
 div(class = "apmenu apline apref", HTML(webtext[webtext$Element == "ds.menu", 
         "Content"]), style = "margin-left:25%")
       ), 
       
  column(9,  
    div(class = "apmargin", 
      div(class = "aptitle",  h1(webtext[webtext$Element == 
                                           "ds.dr.title", "Content"])), br(),
      div(class = "apkicker", h2(webtext[webtext$Element == 
                                           "ds.dr.kicker1", "Content"])),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.dr.kicker1text", "Content"])), br(),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.dr.kicker2text", "Content"])), br(),
      div(class = "apkicker", h2(webtext[webtext$Element == 
                                   "ds.dr.kicker2","Content"])),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.dr.kicker3text", "Content"])), br(),
      div(class = "apkicker", h2(webtext[webtext$Element == 
                                  "ds.dr.kicker3","Content"])),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.dr.kicker4text", "Content"])),
      div(class = "apsubkicker", h3(webtext[webtext$Element == 
                                     "ds.dr.subkicker1", "Content"])),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.dr.subkicker1text", "Content"])),
      div(class = "apsubkicker", h3(webtext[webtext$Element == 
                                    "ds.dr.subkicker2", "Content"])),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.dr.subkicker2text", "Content"])),
      div(class = "apsubkicker", h3(webtext[webtext$Element == 
                                    "ds.dr.subkicker3","Content"])),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.dr.subkicker3text", "Content"])),
      div(class = "apsubkicker", h3(webtext[webtext$Element == 
                                    "ds.dr.subkicker4","Content"])),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                       "ds.dr.subkicker4text", "Content"])),
      div(class = "apsubkicker", h3(webtext[webtext$Element == 
                                         "ds.dr.subkicker5","Content"])),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                    "ds.dr.subkicker5text", "Content"])),
      div(class = "apsubkicker", h3(webtext[webtext$Element == 
                                         "ds.dr.subkicker6","Content"])),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                     "ds.dr.subkicker6text", "Content"])),
      div(class = "apsubkicker", h3(webtext[webtext$Element == 
                                         "ds.dr.subkicker7", "Content"])),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                  "ds.dr.subkicker7text", "Content"])), br(),
      div(class = "apkicker", h2(webtext[webtext$Element == 
                                 "ds.dr.kicker4","Content"])),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                   "ds.dr.subkicker8text","Content"])), br(),
      div(class = "apkicker", h2(webtext[webtext$Element == 
                                           "ds.dr.kicker5","Content"])),
      div(class = "apkickertext", HTML(webtext[webtext$Element == 
                                   "ds.dr.subkicker9text", "Content"])), br()
        ) # End of division margins  
       ) # End of column  
     ) # End of fluidRow    
 )  #End of Tab Panel
), # End navbarMenu
 
 
# User Support Page
tabPanel(h4("User Support"), value = "#UserSupport",
   div(class = "phototext", 
       style = webfoto[webfoto$Element == "us.banner", "Filename"], 
       alt   = webfoto[webfoto$Element == "us.banner", "Alttext"]
#      title = webfoto[webfoto$Element == "us.banner", "Title"]
   ),

# Breadcrumbs         
   fluidRow (
     column(3, style = "background-color:#d7e4ee;height:93em;", offset =  0, 
            p(tags$ol(div(class = "breadcrumb",
              tags$li(tags$a(href = "#Home", "Home")),
              tags$li("User Support"))
            ))
# User
# div(class = "apmenu apline apref", 
# HTML(webtext[webtext$Element == "ds.menu", 
# "Content"]), style = "margin-left:25%")
   ), # column end
 
column(9,
       div(class = "scenmargin",
           div(class = "aptitle", h1(webtext[webtext$Element == 
                "us.title", "Content"])),br(),
#           div(class = "apkicker", h2(webtext[webtext$Element == 
#               "us.kicker1", "Content"])), br(),
           
#Videos       
 fluidRow(    
   column(2, offset=0 
#         div(icon("file-video-o", lib = "font-awesome", "fa-6x"), 
#         style="color:#1F8BBF"), align = "left"
         ),
   column(8,
          h3(HTML(webtext[webtext$Element == 
                "us.support1title", "Content"]),style="color:#1F8BBF"), 
    fluidRow(    
      column(4, 
         tags$a(HTML(webtext[webtext$Element == 
             "us.video1", "Content"]),
          tags$img(src  = webfoto[webfoto$Element == "us.video1","Filename"], 
           alt   = webfoto[webfoto$Element == "us.video1","Alttext"], 
           title = webfoto[webfoto$Element == "us.video1","Title"],                                       
           width = "95%"),
         h5(webtext[webtext$Element == 
         "us.video1caption", "Content"], align="center")
         )
      ),
      column(4, 
         tags$a(HTML(webtext[webtext$Element == 
                "us.video2", "Content"]),
           tags$img(src  = webfoto[webfoto$Element == "us.video2","Filename"], 
           alt   = webfoto[webfoto$Element == "us.video2","Alttext"], 
           title = webfoto[webfoto$Element == "us.video2","Title"],                                       
                 width = "95%"),
           h5(webtext[webtext$Element == 
           "us.video2caption", "Content"], align="center")
        )
      ),
       column(4, 
         tags$a(HTML(webtext[webtext$Element == 
              "us.video3", "Content"]),
            tags$img(src  = webfoto[webfoto$Element == "us.video3","Filename"], 
              alt   = webfoto[webfoto$Element == "us.video3","Alttext"], 
              title = webfoto[webfoto$Element == "us.video3","Title"],                                       
              width = "95%"),
            h5(webtext[webtext$Element == 
            "us.video3caption", "Content"], align="center")
         )
            ) # End Column
           
          ) # end of fluidRow                
   ) #end column
 ), hr(),  #End Videos fluid row            

# Quick Guide
fluidRow(
  tags$a(href = "ITHIM_quickguide.pdf",
  column(2, offset=0,
     tags$img(src = webfoto[webfoto$Element == "us.quickguide", "Filename"], 
         alt = webfoto[webfoto$Element == "us.quickguide", "Alttext"], 
       title = webfoto[webfoto$Element == "us.quickguide", "Title"],                     
         width = "50%"), 
     align = "left"), 
  column(8,
         h3(HTML(webtext[webtext$Element == 
             "us.cheatsheet", "Content"])) 
  ) #end column
  ) # end tag
), hr(),  #End fluid row


# User Manual                  
fluidRow(
  tags$a(href = "ITHIM_manual.pdf",
         column(2, offset=0,
            tags$img(src = webfoto[webfoto$Element == "us.manual", "Filename"], 
                alt = webfoto[webfoto$Element == "us.manual", "Alttext"], 
                title = webfoto[webfoto$Element == "us.manual", "Title"],                     
                width = "50%"), 
            align = "left"), 
         column(8,
                h3(HTML(webtext[webtext$Element == 
                   "us.manual", "Content"])),
                p(HTML(webtext[webtext$Element == 
                            "us.worksheet", "Content"]))
         ) #end column
  ) # end tag
), hr(),  #End fluid row

# chartbook                  
# fluidRow(
#     column(2, offset=0,
#      tags$img(src = webfoto[webfoto$Element == "us.chartbook", "Filename"], 
#          alt = webfoto[webfoto$Element == "us.chartbook", "Alttext"], 
#          title = webfoto[webfoto$Element == "us.chartbook", "Title"],                     
#          width = "50%"), 
#      align = "left"), 
#     column(8,
#            h3(HTML(webtext[webtext$Element == 
#                "us.chartbooktitle", "Content"]), style="color:#1F8BBF"),
#            h5(HTML(webtext[webtext$Element == 
#                "us.chartbook", "Content"])) 
#     ) #end column
# ), hr(),  #End fluid row

# Upload instructions
fluidRow(
   column(2, offset=0,
        div(tags$img(src = webfoto[webfoto$Element == "us.upload", "Filename"], 
          alt = webfoto[webfoto$Element == "us.upload", "Alttext"], 
          title = webfoto[webfoto$Element == "us.upload", "Title"],                     
          width = "50%"), 
        align = "left", style = "margin-top:25px")), 
   column(8,
           h3(HTML(webtext[webtext$Element == 
              "us.uploadtitle", "Content"]), style="color:#1F8BBF"),
           h5(HTML(webtext[webtext$Element == 
              "us.upload", "Content"]))
         ) #end column
), hr(),  #End fluid row


# Workshop slides                  
fluidRow(
  tags$a(href = "ITHIM_workshop.pdf",
    column(2, offset=0,
      tags$img(src = webfoto[webfoto$Element == "us.workshop", "Filename"], 
           alt = webfoto[webfoto$Element == "us.workshop", "Alttext"], 
           title = webfoto[webfoto$Element == "us.workshop", "Title"],                     
           width = "50%"), 
      align = "left"), 
    column(8,
           h3(HTML(webtext[webtext$Element == 
              "us.workshop", "Content"])) 
    ) #end column
  ) # end tag
), hr(),  #End fluid row

      
# R Code
fluidRow(
  column(2, offset=0,
     div(tags$img(src = webfoto[webfoto$Element == "us.Rcode", "Filename"], 
                  alt = webfoto[webfoto$Element == "us.Rcode", "Alttext"], 
                  title = webfoto[webfoto$Element == "us.Rcode", "Title"],                     
                  width = "50%"), 
         align = "left", style = "margin-top:20px")), 
  column(8,
         h3(HTML(webtext[webtext$Element == 
              "us.Rcodetitle", "Content"]), style="color:#1F8BBF"),
         h5(HTML(webtext[webtext$Element == 
                "us.Rcode", "Content"]))
  ) #end column
), hr(),  #End fluid row


# Glossary
fluidRow(
  tags$a(href = "ITHIM_glossary.pdf",
     column(2, offset=0,
       tags$img(src = webfoto[webfoto$Element == "us.glossary", "Filename"], 
                alt = webfoto[webfoto$Element == "us.glossary", "Alttext"], 
                title = webfoto[webfoto$Element == "us.glossary", "Title"],                     
                width = "50%"), 
       align = "left"), 
     column(8,
            h3(HTML(webtext[webtext$Element == 
               "us.glossary", "Content"])) 
     ) #end column
  ) # end tag
)   #End fluid row
        
                    ) # End of margin division  
             ) # End of column  
           ) # End of fluidRow    
       )  #End of Tab Panel
   
   ) # Nav Bar Page
  ) # End of Fluid Page

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Server Side Shiny
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

server <- function(input,output, session) {

  callModule(ithim_tool, "TOOL")
  
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# About> Geography> Tables
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  
  output$regions  <- renderTable(regions)
  output$counties <- renderTable(counties)
  
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Home Page Action Buttons
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  observeEvent(input$about_tool, {
    updateNavbarPage(session = session, inputId = "tabs", 
                     selected = "#Introduction")
  })
 observeEvent(input$use_tool, {
    updateNavbarPage(session = session, inputId = "tabs", 
                     selected = "#Instructions")
  }) 
  observeEvent(input$go_tool, {
    updateNavbarPage(session = session, inputId = "tabs", 
                     selected = "#RunITHIM")
  })   
 
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Navigation for footer and between pages
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  
  observeEvent(input$tabs, {
    
    if (getUrlHash() == input$tabs) return()
    updateQueryString(
      paste0(getQueryString(), input$tabs),
      "push"
    )
  }, ignoreInit = TRUE)
  observeEvent(getUrlHash(), {
    hash <- getUrlHash()
    if (hash == input$tabs) return()
    valid <- c("#Home", "#About", "#Scenarios", "#Geographies", "#TimePeriods",
               "#Feedback","#Introduction", "#Instructions", "#Methods",  
               "#RunITHIM", "#DecisionSupport", "#Health",  
               "#IntroStrategies", "#PhysicalActivity", "#Safety",
               "#AirPollution", "#Evidence", "#Data", "#UserSupport")
    if (hash %in% valid) {
      updateTabsetPanel(session,"tabs", hash)
      }
  })   
 
} # End Server
shinyApp(ui = ui, server = server)
