# This set of functions dynamically generate html/css for creating tables.

library(shiny)
if(require(ggplot2)==F){
  install.packages("ggplot2")
  library(ggplot2)
}
# if(require(ggrepel)==F){
#   install.packages("ggrepel")
#   library(ggrepel)
# }

# Colors ----
# Note: do not change the order of the colors, simply modify or append.
# CARB Colors
colores <- c('#3e7195',  # 1 medium blue
             '#064b6a',  # 2 dark blue
             '#064b6a',  # 3 dark blue
             '#FDB727',  # 4 gold
             '#4D4D4F'   # 5 charcoal
)

# Other colors
otros_colores <- c("white",  # 1 text
                   "black",  # 2 text, black
                   "#A4A4A4",  # 3 time update color
                   "#d7e4ee",  # 4 background light blue
                   "#8cd9cd",  # 5 lighter colors[3] for ggplot bars.
                   "#b2b2b3",  # 6 background grey's shadow
                   "#f2f2f2",  # 7 background grey's highlight
                   "#98cdc5"  # 8 Less saturated 5.
)

# Some repeated styles:
styles <- list(
  # dashed line.
  vertical_rule=paste0("border-left: 0.1em dashed ", otros_colores[1], "; "),
  # minimalist padding.
  minimal_padding=paste0("padding-left:0.2em; ",
                         "padding-right:0.2em; ",
                         "margin:0em; "),
  # Dashed Line
  horizontal_rule1=paste0("<hr style='",
                         "border:0; ",
                         "border-bottom: 0.1em dashed ",
                         otros_colores[1],
                         "; ",
                         "background: ",
                         otros_colores[4],
                         "; ",
                         "'>"),
  # 70% Line, Gradient, Background Grey
  horizontal_rule2=paste0("<hr width='70%' style='",
                          "border: 0; ",
                          "height: 1px; ",
                          "background-image: ",
                          "linear-gradient(to right, #fff, ",
                          otros_colores[4],
                          ", #fff); ",
                          "'>")
)



# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#' Find and Replace text with HTML <a> tags.
#' 
#' @param text is a string
#' @return some text that should be utilized in the fn shiny::HTML()
# fn_linkTagger <- function(text){
#   for(i in seq_len(nrow(d$links))){
#     if (grepl(pattern = d$links[i, "regex"],
#               x = text)) {
#       tmp <- strsplit(x = text,
#                       split = d$links[i, "regex"])[[1]]
#       text <- paste0(
#         tmp[1],
#         '<a href="',
#         d$links[i, "url"],
#         '">',
#         d$links[i, "regex"],
#         '</a>',
#         tmp[2]
#       )
#     }
#   }
#   
#   # return
#   text
# }

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# FUNCTION GROUP ----
# Regular Expression Substitutions
# Primary: fn_keyworder
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#' See fn_keyworder
fn_regexChar <- function(x, df) {
  if (class(x) %in% c("character", "factor")) {
    # convert if its a factor.
    if (class(x) == "factor")
      x <- as.character(x)
    # Go through character vector and replace each element's matches for
    # regular expressions based on the `df`.
    out <- sapply(x, function(z) {
      # Check for {key}
      if (grepl("\\{\\w{1,}\\}", z, perl = T)) {
        # Ok, so since {key} is present...
        
        # get string match attributes using regular expressions
        k <- gregexpr("\\{\\w{1,}\\}", z, perl = T)[[1]]
        # get list with the beginning/end of each {key} in the string `z`.
        k <- lapply(seq_along(k), function(aa) {
          start <- k[aa]
          end <- start + attributes(k)$match.length[aa] - 1
          list(start = start, end = end)  # return for lapply
        })
        # extract each {key}, create two var: k & subtext
        subtext <- k <- sapply(seq_along(k), function(aa) {
          # return for lapply
          substr(z, start = k[[aa]]$start, stop = k[[aa]]$end)
        })
        # modify subtext for regex pattern matching.
        subtext <- sapply(seq_along(subtext), function(aa) {
          # append/prepend backslashes for later string substition.
          sub("\\{",
              "\\\\\\{",
              sub("\\}", "\\\\\\}", subtext[aa], perl = T),
              perl = T)
        })
        
        # error checking
        if (F %in% (k %in% df$key))
          stop("Error fn_regexChar: Missing keys.")
        if (length(subtext) != length(k))
          stop("Error fn_regexChar: Subtext is wrong length.")
        
        # For each `k` replace `z` based on table
        for (i in seq_along(k)) {
          z <- sub(subtext[i], 
                   df$value[df$key == k[i]], 
                   z, 
                   perl = T)
        }
        # return
        z
      } else
        # No {key} present, thus just return z without doing anything.
        z  # return
    })  # end sapply for character vector.
    unname(out)  # return
  } else
    NULL  # not a character or factor.
}

#' Systematically substitutes particular keywords in strings with a dynamically
#' selected term. All keywords are encased in curly braces, {}. In the ITHIM
#' TOOL, curly braces alongside certain keywords are reserved specifically for
#' the use by this function. This function was created in response to the need
#' for certain units, such as miles vs. kilometers to be used interchangeably
#' based on what the user selected. Importantly, this function does nothing
#' beyond changing strings (i.e. the aesthetic portions of ITHIM TOOL).
#' 
#' @param x is some string in the form of a vector or data.frame.
#' @param lookup is a lookup table for the keys of interest, typically this is
#' sourced from l$centrality, l$at_time_unit, l$td_unit, l$td_time. The
#' data.frame itself is composed of two columns: key and value. The key column
#' should contain strings in the format {key}.
fn_keyworder <- function(x, lookup){
  if(class(x) == "data.frame"){
    # DATA.FRAMES
    # So, if data.frame, for EACH COLUMN...
    x <- lapply(x, function(y){
      # Check if column is character/factor...
      if(class(y) %in% c("character", "factor")) {
        # Since column is character/factor, then...
        fn_regexChar(y, lookup)
      } else  # Not a character column? So just return y.
        y  # return
    })  # end of first lapply
    as.data.frame(x, stringsAsFactors = F)  # return
    
  } else if (class(x) %in% c("character", "factor")){
    # VECTOR
    # Since column is character, then...
    fn_regexChar(x, lookup)  # return
    
  } else {
    # NONE OF THE ABOVE
    NULL  # return
  }
}

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# FUNCTION GROUP ----
# The below functions create the tables.
# Primary: fn_tableManager
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#' Creates data.frame for directing the creation of spanning column headers.
#' 
#' @param cs is the string for the colspans.
#' @return data.frame listing headers for those tables with spanning.
fn_colspans <- function(cs) {
  # Return null if there is no spanning column headers.
  if(is.null(cs) | is.na(cs) | cs=="" | length(cs)==0) return(list())
  
  # Convert each header into its own list element
  cs <- as.list(strsplit(cs, split="\\;{3}", perl=T)[[1]])
  
  cs <- lapply(cs, function(x){
    x <- strsplit(x, split="\\,{3}", perl=T)[[1]]
    # return
    data.frame(cell_text=x[1], 
               rows=x[2], 
               cols=x[3], 
               stringsAsFactors = F)
  })
  
  cs <- do.call(rbind, cs)
  
  cs  # return
}
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# FUNCTION: Column Reformatter
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#' Reformats a column from a data.frame, and thus converts the column into
#' characters. It will ignore character columns, and will convert columns
#' that are not characters or doubles into characters (eg. integer to
#' character).
#' 
#' @param co column in data.frame
#' @return column in data.frame
fn_formattr_col <- function(co, lo){
  # Weed out non-doubles.
  if(is.character(co)) {
    return(co)
  } else if(!(is.double(co))) {
    return(as.character(co))
  } else {  # ie. doubles:
    co <- sapply(co, function(x) format(x,
                  nsmall = lo,  # how many decimal places to show
                  digits = lo,  # sig figs
                  trim=T,
                  scientific = F,  # do not convert to sci notation
                  big.mark = ",")  # add thousands separator
    )
    
    # Check for values with long decimal values.
    ml <- sapply(gregexpr("\\.\\d+", co, perl=T), 
                 function(x) attr(x, "match.length"))
    
    # Check where period is in string.
    ml_tooLong <- sapply(gregexpr("^[\\d\\,]+\\.", co, perl=T),
                         function(x) attr(x, "match.length"))
    
    
    # # Do we want Scientific Notation?
    # Turn to scientific notation if too many decimal values.
    # Note, only works if lo > 0.
    # co <- unname(mapply(function(x, ml){
    #   # if more than three digits convert to sci notation.
    #   if(ml > 3) {
    #     format(as.double(x),
    #            digits=2,
    #            scientific = T  # convert to sci notation
    #     )
    #   } else {x}  # else just return x.
    # },
    # x=co,
    # ml=ml))
    
    # Do we want a cut off instead of Scientific Notation?
    co <- unname(
      mapply(
        function(x, ml) {
          if(ml > 2) {
            return("< 0.1")
          } else {
            return(x)
          }
        }, 
        x=co, 
        ml=ml)
    )
    
    # Do we want to remove decimal if too long?
    co <- unname(
      mapply(
        function(x, ml_tooLong) {
          if(ml_tooLong > 3) {
            return(
              # convert string to shorter string.
              format(
                as.double(
                  gsub("\\,", "",x)),  # remove commas before convert to num.
                trim=T, 
                digits=0, 
                scientific=F, 
                big.mark=","))
          } else {
            return(x)
          }
        }, 
        x=co, 
        ml_tooLong=ml_tooLong)
    )
    
    # Replace NA values with another character
    co[grepl("NA", co, perl=T)] <- "---"
    # Replace NaN values with 0 (as requested by NM 2019-03-20)
    co[grepl("NaN", co, perl=T)] <- "0"
    return(co)
  }
}

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# FUNCTION: Data.frame Reformatter
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#' Applies above fn_formattr_col to a single data.frame.
#' 
#' @param l is the list with "titles", "sigfigs" and "df_list"
#' @return l with improved df_list
fn_formattr_df <- function(l){
  
  # save attributes to re-label after wrecking it.
  titles <- sapply(l$df_list, function(x){
    attributes(x)$df_name
  })
  df_id <- sapply(l$df_list, function(x){
    attributes(x)$df_id
  })
  
  lo <- l$sigfigs
  l$df_list <- lapply(seq_along(l$df_list), function(i){
    o <- as.data.frame(
      do.call(cbind, 
              lapply(l$df_list[[i]], function(x) fn_formattr_col(x, lo))
      ),
      stringsAsFactors=F)
    nm <- colnames(o)
    nm <- unname(sapply(nm, function(x)
      if(TRUE %in% grepl("\\.", x, perl=T)){
        gsub("\\.", " ", x)
      }
      else {x}
    ))
    colnames(o) <- nm
    o  # return
  })
  
  # relabel data.frames with ithim_tool_strings.csv's rp.XXXlist names.
  l$df_list <- lapply(seq_along(l$df_list), function(i){
    structure(l$df_list[[i]],
              df_name=titles[i],
              df_id=df_id[i])
  })
  
  # Fix 0 billion dollar values
  if(T %in% grepl("[cC]osts", titles, perl=T)) {
    l$df_list <- lapply(seq_along(l$df_list), function(i){
      df <- l$df_list[[i]]
      # STab1
      if(attr(df, "df_name") ==
         paste0("Annual Changes in Active Travel Time, ",
                "Deaths, Costs, and Carbon Emissions,  ")) {
        if(df[3, "Scenario"]=="0"){
          df[3, "Scenario"] <- "<< $1 billion"
        } 
      }
      if(attr(df, "df_name") == 
         paste0("Annual Cost Savings of Health Benefits ",
                "(billions of 2010 dollars),  ")){
        if(df[1,"Dollars"]=="0") {
          df[1,"Dollars"] <- "<< $1 billion"
        }
        if(df[2,"Dollars"]=="0") {
          df[2,"Dollars"] <- "<< $1 billion"
        }
      }
      # Return
      df
    })
    
  }
  
  
  # o <- lapply(df, function(x) fn_formattr_col(x, lo))
  # o <- as.data.frame(do.call(cbind, o), stringsAsFactors=F)
  # nm <- colnames(o)
  # nm <- unname(sapply(nm, function(x)
  #   if(TRUE %in% grepl("\\.", x, perl=T)){
  #     gsub("\\.", " ", x)
  #   }
  #   else {x}
  # ))
  # colnames(o) <- nm
  # attr(o, "component") <- "table_core"
  # o  # return
  
  l  # return
}

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# FUNCTION: HTML Table Generator
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#' Creates HTML output using shiny::tags for an ITHIM table. 
#' Note: CSS is sourced from a separate document: fn_ithimTabler.css
#'
#' @param tc contains table components (titles, colspans, STabs)
#' @return a string.
# fn_ithimTabler <- function(tc){
#   
#   # Subset the core part of the table (i.e. sans header)
#   core <- tc[sapply(tc, function(x) attr(x, "component")=="table_core")]
#   
#   # Create an empty output list to which to add HTML tables as we build them.
#   out <- sapply(seq_along(core), function(x) NULL)
#   
#   # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#   # Create each table using a for loop.
#   for(i in seq_along(core)){
#     
#     # Error Checking.
#     # check to make sure there are no factors.
#     if(is.factor(core[[i]][1])) stop(
#       "Error in fn_ithimTabler: The data.frame must not have factors.")
#     # check to make sure it is a data.frame.
#     if(!(is.data.frame(core[[i]][1]))) stop(
#       "Error: fn_ithimTabler list not of data.frames")
#     
#     df <- core[[i]]  # current table (i.e. data.frame).
#     
#     # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#     # Begin constructing HTML code.
#     # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#     
#     # Create a list for output & starting tags.
#     l <- list(first='<div class="ithimTableDiv">')
#     
#     # retrieve table title
#     # TODO delete.
#     # ti <- tc[["titles"]][i]
#     ti_r <- tc[["title_roots"]][i]
#     
#     # TODO delete.
#     # # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#     # # Table Title
#     # # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#     # title <- paste('<h4 class="ithimTableh4">', 
#     #                tc[["titles"]][i],
#     #                '</h4>',
#     #                styles$horizontal_rule2)
#     # l <- append(l, title)
#     
#     # Create Table opening tags
#     l <- append(l, list(table_start='<table class="ithimTable"> <tbody>'))
#     
#     headers <- list()
#     
#     # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#     # Spanned Headers
#     # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#     # If colspans is present, add a spanned header column.
#     # note spanned here refers to how tables are presented, not HTML tag <span>.
#     if(ti_r %in% unique(tc$colspans$table_name)) {
#       # subset spanning header data.frame for this table.
#       cdf <- tc$colspans[which(tc$colspans$table_name==ti_r),]
#       col_num <- ncol(df)  # total number of columns
#       
#       header_list <- list()  # create empty list to which to add HTML code.
#       top <- c('<tr class="ithimTableSH">')  # opening line for row.
#       bot <- c('</tr>')  # closing line for row.
#       
#       col_counter <- 0  # keep track of column length in forloop
#       
#       # Using shiny::tags
#       ths <- list()
#       
#       # Create 
#       for(th in seq_len(nrow(cdf))){
#         if(col_counter == 0) header_list <- append(header_list, top)  # open tr
#         
#         # Create body of this row's header.
#         tmp <- paste0('<th ',  # open th
#               'rowspan="',
#               cdf$rows[th],
#               '" ',
#               'colspan="',
#               cdf$cols[th],
#               '">',
#               cdf$cell_text[th],
#               '</th>'  # close th
#               )
#         
#         # Using shiny::tags
#         # add each th to th list.
#         ths <- append(headers, 
#                           tags$th(rowspan=cdf$rows[th], 
#                                   colspan=cdf$cols[th],
#                                   cdf$cell_text[th]))
#         
#         # Add the current row to the header list (later to be added to l)
#         header_list <- append(header_list, tmp)
#         # Increment the counter.
#         col_counter <- col_counter + as.numeric(cdf$cols[th])
#         # Error checking.
#         if(col_counter > col_num) stop(paste("Error: spanning header",
#                                              "improperly formatted."))
#         # Reset counter & add closing tag for tr
#         if(col_counter == col_num) {
#           col_counter <- 0
#           header_list <- append(header_list, bot)  # close tr
#           }
#       }
#       
#       # Using shiny::tags
#       headers <- tags$tr(class="ithimTableSH",
#                          unlist(ths))
#       
#       # combine all tr into a single string
#       header_list <- paste(header_list, collapse=" ")
#       # Append spanning headers to l
#       l <- append(l, header_list)
#       # Garbage Collection
#       rm(th, tmp, top, bot, header_list, col_counter)
#     } else {
#     # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#     # Normal Headers
#     # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#     
#       # get column names.
#       hd <- colnames(df)
#       
#       # Replace underscores with spaces.
#       hd <- sapply(hd, function(x) {
#         if(TRUE %in% grepl("\\_", x, perl=T)) {
#           x <- gsub("\\_", " ", x, perl=T)
#         }
#         x})
#       
#       # Begin html for headers with tr.
#       l <- append(l, '<tr>')
#       # Create first header.
#       th1 <- paste('<th style="text-align: left;">',
#                    hd[1],
#                    '</th>')
#       
#       # Using shiny::tags
#       headers <- append(headers,
#                         tags$th(style="text-align: left;",
#                                 hd[1]
#                         ))
#       
#       # Create the rest of the headers.
#       # TODO see if this crashes with only one column in data.frame.
#       th_theRest <- 
#         paste(
#           sapply(hd[2:length(hd)], 
#                  function(nm) paste0('<th>',nm,'</th>')),
#           collapse=" ")
#       
#       # Using shiny::tags
#       headers <- append(headers,
#                         sapply(th_theRest, tags$th)
#                         )
#       
#       # combine all headers
#       header <- paste(th1, th_theRest, collapse=" ")
#       
#       # add headers to list.
#       l <- append(l, header)
#       l <- append(l, '</tr>')
#     }
#     
#     # Using shiny::tags
#     headers <- tags$tr(headers)
#     
#     rows <- list()
#     
#     # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#     # Rows
#     # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#     for(j in seq_len(nrow(df))){
#       # extract row
#       tmp <- as.character(df[j,])
#       
#       # Using shiny::tags
#       row <- tags$tr(
#         # first item
#         tags$td(style="text-align: left;",
#                 tmp[1]),
#         # rest of row items
#         sapply(tmp[2:length(tmp)], tags$td)
#       )
#       
#       rows <- append(rows,  # previous completed rows
#                      row)  # current row
#       
#       # create first row item.
#       td1 <- paste('<td style="text-align: left;">',
#                    tmp[1],
#                    '</td>')
#       
#       # create rest of row items.
#       td_theRest <- 
#         paste(
#           sapply(tmp[2:length(tmp)], 
#                  function(nm) paste0('<td >',
#                                      nm,
#                                      '</td>')),
#           collapse=" ")
#       
#       # combine all row items into one row.
#       row <- paste('<tr>', td1, td_theRest, '</tr>', collapse=" ")
#       
#       # append row to list.
#       l <- append(l, row)
#       rm(row, tmp)  # clean up
#     }
#     rm(j)
#     
#     # Using shiny::tags
#     table <- tags$div(class="ithimTableDiv"
#       
#     )
#     
#     # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#     # Add ending tags for table.
#     end <- list(end='</tbody></table></div>')
#     l <- append(l, end)
#     
#     # Put headers and rows together.
#     
#     
#     # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#     out[[i]] <- paste(l, collapse=" ")
#     rm(l)
#   }
# 
#   out  # return
# }

#' This function creates the HTML table output
#' 
#' @param tc contains table components (titles, colspans, STabs)
fn_tableTagger <- function(l){
  
  
  # Create variables with shorter
  # variable names for coding
  # expediency.
  scenario <- l$scenario$name
  yr <- l$fYear
  geo <- l$fGeography
  table_str <- l$table_str
  
  # TODO find alternative method to do the following:
  # Temporary fix, to append "County" to counties.
  if(!(geo %in% c(
    "California",
    "Sacramento Area",
    "San Diego County",
    "San Joaquin Valley",
    "SF Bay Area",
    "Southern California"
  ))){
#    geo <- paste(geo, "County")
    geo <- paste0(geo, "")  
  }
  
  # Subset the core part of the table (i.e. sans header)
  # core <- tc[sapply(tc, function(x) attr(x, "component")=="table_core")]
  core <- l$df_list
  
  # Get names of tables with spanning column headers.
  cs_tables <- table_str[!is.na(table_str$spanning_header),"id"]
  
  # Create an empty output list to which to add HTML tables as we build them.
  out <- sapply(seq_along(core), function(x) NULL)
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Create each table using a for loop.
  for(i in seq_along(core)){
    
    citation_counter <- 1
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Get current data.frame/table
    df <- core[[i]]
    
    # Get name of current table/data.frame
    nm <- attributes(core[[i]])$df_name
    
    # Get ID of current table/data.frame
    id <- attributes(core[[i]])$df_id
    
    # Get table_num
    table_num <- table_str$table_num[table_str$id == id]
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Table Headers ----
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    if(id %in% cs_tables) {
      # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      # Table with Spanning Headers.
      # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      # If colspans is present, add a spanned header column.
      # note spanned here refers to how tables are presented, 
      # not HTML tag <span>.
      
      cdf <- fn_colspans(table_str$spanning_header[table_str$id == id])
      
      # subset spanning header data.frame for this table.
      # cdf <- l$cs[which(l$cs$table_name==ti_r),]
      
      # create variables for the loop to assign table rows <tr>'s
      col_num <- ncol(df)  # total number of columns
      tr_tracker <- 1  # track number of table rows
      col_counter <- 0  # track which column
      
      # loop to assign table rows <tr>'s
      for(cc in seq_len(nrow(cdf))){
        col_counter <- col_counter + as.numeric(cdf$cols[cc])
        cdf$tr[cc] <- tr_tracker  # save table row (tr) number
        if(col_counter==col_num){
          tr_tracker <- tr_tracker + 1
          col_counter <- 0
        }
      }
      
      # split data.frame by number in sequence of table rows (<tr>)
      headers <- split(cdf, cdf$tr)
      # add both <th> and <tr> tags
      headers <- lapply(headers, function(x) {

        tmp <- list()
        for(th in seq_len(nrow(x))){
          
          if(grepl("XX", x$cell_text[th])){
            # Add Citations
            cell_txt <- sub("XX",
                paste0(tags$sup(as.character(citation_counter))),
                x$cell_text[th],
                perl=T)
            citation_counter <<- citation_counter + 1
          } else {
            # No Citations
            cell_txt <- x$cell_text[th]
          }
          
          tmp <- append(tmp,
                        list(tags$th(rowspan=x$rows[th], 
                                     colspan=x$cols[th],
                                     HTML(as.character(cell_txt))))
          )
        }
        tags$tr(class="ithimTableSH",
                tmp)
      })
      
    } else {
      # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      # Table Headers (without spanning).
      # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      # get column names.
      hd <- colnames(df)
      
      # Replace underscores with spaces &
      # replace "XX" with citation_number
      hd <- sapply(hd, function(x) {
        if(TRUE %in% grepl("\\_", x, perl=T)) {
          x <- gsub("\\_", " ", x, perl=T)
        }
        if(TRUE %in% grepl("XX", x, perl=T)){
          x <- sub("XX",
                   paste0(tags$sup(as.character(citation_counter))),
                   x,
                   perl=T)
          citation_counter <<- citation_counter + 1
        }
        x
        })
      
      # assign table header to first cell/left hand column
      th1 <- tags$th(style="text-align: left;",
                     HTML(hd[1]))
      
      # assign table header to everything to the right of above.
      th_rest <- lapply(hd[2:length(hd)], function(x){
        tags$th(HTML(x))
      })
      
      headers <- tags$tr(class="ithimTableSH",
                         th1, 
                         th_rest)
    }  # end of headers
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Table Rows ----
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Creates the core of the table using
    # HTML tags for tables.
    # The anonymous function in this
    # apply() functional creates HTML tags
    # for a single row in the data.frame
    # `df`. It is possible to include in-
    # text citation (superscripts) for the
    # header column by including the
    # string "XX" somewhere in the cell.
    # It's important to note that this
    # function expects only a single in-
    # text citation per cell!
    rows <- apply(
      X = df,
      MARGIN = 1,
      FUN = function(row) {
      # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      # COLUMN 1
      # inserting citation: 
      # important point here, assumes only one per cell.
      if(grepl("XX", row[1])){
        # Citation Notation in Header Column
        
        # row[1] <- sub("\\*{2}", tags$sup(citation_counter), row[1])
        # td1 <- strsplit(row[1], "XX", perl=T)[[1]]
        td1 <- tags$td(
          style="text-align: left;",
          HTML(sub("XX", 
                   tags$sup(as.character(citation_counter)), 
                   row[1])
          )
        )
        # increase counter for citation number.
        citation_counter <<- citation_counter + 1
        
      } else {
        # No Citation Notation in Header Column
        td1 <- tags$td(
          style="text-align: left;",
          row[1]
          )
      }
      
      # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      # COLUMNS 2 THROUGH ncol()
      td_rest <- lapply(row[2:length(row)], function(x){
        tags$td(x)
      })  # end of lapply
      
      # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      tags$tr(td1, td_rest)  # return
    })
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Table Title ----
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    current_title <- gsub(pattern="\\s{2,}",
                          replacement=" ",
                          x=paste0(table_num,  # Number in series
                                   ". ",
                                   nm,  # Name of table.
                                   ", ",
                                   geo,  # Geography.
                                   ", ",
                                   scenario,  # Scenario Name.
                                   ", ",
                                   yr  # Year.
                          )
    )

    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Table Footnotes ----
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # note: table_units defined in app.R
    # if(l$table_units == "default") 
    #   mycol <- "units1"
    
    footnotes <- table_str[table_str$id == id, "footnotes"]
    
    # # The below code will format footnotes with numbers/newlines/periods.
    # if(footnotes != "") {
    #   # Styling footnotes.
    #   footnotes <- strsplit(footnotes, "\\;", perl=T)[[1]]
    #   footnotes <- paste(paste0(seq_along(footnotes), "."), footnotes)
    #   footnotes <- paste(footnotes, collapse=". ")
    # }
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Create Table tagList ----
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    if("" %in% footnotes){
      # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      # No footnotes
      # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      out[[i]] <- tags$div(
        tags$h4(current_title, class="ithimTable_title"),
        tags$table(class="ithimTable",
                             tags$tbody(headers,
                                        rows)),
        class="ithimTable_outer_box"
      )
      
    } else {
      # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      # Footnotes present.
      # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      out[[i]] <- tags$div(
        tags$h4(current_title, class="ithimTable_title"),
        tags$table(class="ithimTable",
                   tags$tbody(headers,
                              rows)),
        tags$br(),
        tags$div(
          # tags$p(tags$em(tags$b("Terms")), class="ithimTable_em"),
          lapply(footnotes, function(x){
            tags$p(x, class="ithimTable_footnotes")
          }),
          class="ithimTable_footnotes_block"
        ),
        class="ithimTable_outer_box"
      )
    }  # end if statement for footnotes.
    
  }  # end of table making loop.
  
  # Save tagList object `out` to output object `l`
  l$tagList <- out
  
  l  # return
}

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# FUNCTION: High-Detail Specific Disease Table (Table 3)
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#' Creates a table for a specific disease and pathway. Namely, it creates
#' Table 3. Annual Change in Burden of Disease, Specific Cause
#'
#' @param l is the list object created by run(), with a specific disease
#' @return l with new l$specific_disease_df
fn_specific_disease <- function(l){
  # l$specific_disease should be a single row from d$causes.
  pathway <- l$specific_disease["Pathway"]
  dfcause <- l$specific_disease["dfcause"]
  if(pathway %in% c("PA","PM","RTI")){
    # get the df (generated in ithim_functions.R) from l for this pathway/cause
    o <- l[[paste0(pathway, 
                   "_PAF_", 
                   dfcause)]][1:17, 
                              c("Cause",
                                "Pathway",
                                "Sex",
                                "Age",
                                "change.deaths", 
                                "change.yll", 
                                "change.yld",
                                "change.daly", 
                                "PAF.deaths", 
                                "PAF.yll", 
                                "PAF.yld",
                                "PAF.daly")]
    
  } else if(pathway == "PA+PM"){
    # get the df (generated in ithim_functions.R) from l for this pathway/cause
    o <- l[[paste0("PA+PM_PAF_", 
                   dfcause)]][1:17, 
                              c("Cause",
                                "Pathway",
                                "Sex",
                                "Age",
                                "change.deaths",
                                "change.yll",
                                "change.yld",
                                "change.daly", 
                                "PAF.deaths", 
                                "PAF.yll", 
                                "PAF.yld",
                                "PAF.daly")]
  } else {
    warning("Issue with pathway selection in specific disease visuals.")
  }
  
  # Change sign on Deaths, YLL, YLD, DALY and PAFs
  names(o)[5:8] <- c("Deaths", "YLL", "YLD", "DALY")
  o[5:12] <- -1*o[5:12]
  o[9:12] <- 100*o[9:12]
  
  # add citation for PA
  # names(o)[2] <- "PathwayXX"
  # o[1,2] <- paste0(o[1,2], "XX")
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # depending on if this we're looping
  # through all disease, or if this
  # fn_specific_disease is being called
  # from fn_dataframer, we either want
  # to append the title of the disease
  # to the data.frame, or just return
  # with just the data.frame by itself,
  # because fn_dataframe will rename it
  # later.
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  if(l$specific_disease_title==T) {
    
    # retrieve template titles for summary tables
    # titles <- d$txt$Content[which(d$txt$Element=="rp.httllist")]
    
    title <- d$table_strings$title[d$table_strings$id=="HTab3"]
    
    # separate titles by semi-colon
    # titles <- strsplit(titles, ";")[[1]]
    
    title <- sub("Cause", 
                 l$specific_disease[1, "Cause"], 
                 title)
    
    # append title to data.frame
    o <- structure(o, df_name=title)
    
  } else {
    l$specific_disease_title <- NULL
  }
  
  l$specific_disease_df <- o
  
  l  # return
}

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# FUNCTION: Data.frame maker
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#' Creates list of data.frames for fn_visualDataManager.
#' 
#' @param l is a list from run()
#' @return a list of data.frames.
fn_dataframer <- function(l){
  
  # subset table_strings for current
  # level of detail.
  table_str <- d$table_strings[which(d$table_strings$detail==l$detail),]
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # create lookup table for following
  # fn_keyworder implementation
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  if (!is.null(l$centrality) &
      !is.null(l$at_time_unit) &
      !is.null(l$td_unit) &
      !is.null(l$td_time)) {
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Create strings for lookup table.
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Centrality: MEAN or MEDIAN
    centrality <- l$centrality
    
    centrality2 <- tolower(centrality)  # footnote
    
    # Active travel time unit: minutes per DAY or WEEK
    if(l$at_time_unit=="Day")
      at_time_unit_ly <- "Daily"
    else
      at_time_unit_ly <- "Weekly"
    
    at_time_unit1 <- tolower(l$at_time_unit)  # footnote
    at_time_unit2 <- tolower(at_time_unit_ly)  # footnote
    
    # Travel Distance units: MILES or KILOMETERS
    td_unit <- l$td_unit
    
    # Travel Distance time unit: DAY, WEEK, or YEAR
    td_time <- l$td_time
    
    td_time_ly <- switch(
      td_time,
      "Day" = "Daily",
      "Week" = "Weekly",
      "Year" = "Annual"
    )
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Create lookup table.
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    lookup <- data.frame(
      key = c(
        "{centrality}",
        "{centrality2}",
        "{at_time_unit_ly}",
        "{td_unit}",
        "{td_time}",
        "{td_time_ly}",
        "{at_time_unit1}",
        "{at_time_unit2}"
      ),
      value = c(
        # For Table/Graph Titles
        centrality,
        centrality2,
        at_time_unit_ly,
        td_unit,
        td_time,
        td_time_ly,
        at_time_unit1,
        at_time_unit2
      ),
      stringsAsFactors = F
    )
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Run table_str titles through
    # fn_keyworder to replace {keywords}.
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    table_str <- fn_keyworder(table_str, lookup)
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Save table_str for future functions.
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    l$table_str <- table_str
  } else {
    l$table_str <- NULL
  }
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Create data.frames to be utilized in
  # various visualizations.
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  if(l$detail=="Summary"){
    # ..Summary ----
    
    # # retrieve template titles for summary tables
    # titles <- d$txt$Content[which(d$txt$Element=="rp.sttllist")]
    #
    # # separate titles by semi-colon
    # titles <- strsplit(titles, ";")[[1]]
    
    # # Remove the last comma from the title?
    # if("clean_title" %in% names(l)){
    #   if(l$clean_title==T){
    #     # clean up titles (i.e. remove last comma)
    #     titles <- sapply(titles, function(x){
    #       # get all commas and their trailing whitespaces
    #       commas <- gregexpr("\\,\\s*",
    #                          x,
    #                          perl=T)
    #       
    #       # get integer place of the last one
    #       commas <- commas[[1]][length(commas[[1]])]
    #       
    #       # subset the first letter through to the comma.
    #       substr(x,
    #              start = 1,
    #              stop = commas - 1)
    #     })
    #     l$clean_title <- NULL
    #   }
    # }
    
    # # Error checking.
    # if(length(titles) != 6) stop(
    #   "Error fn_dataframer: summary titles not right length"
    #   )

    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Table 1 - Annual Changes in Active
    # Travel Time, Deaths, Costs, and
    # Carbon Emissions
#    print(l$co2)   
    STab1 <-
      data.frame(
        "Item" = strsplit(table_str[1, "header_column"], "\\;", perl=T)[[1]],
        "Baseline" = c(l$at_sat_wide[17, 6], 
                       NA, 
                       NA, 
                       l$co2[2, 7]),
        "Scenario" = c(l$at_sat_wide[17, 9],
                       -1 * sum(l$cause_sum[
                         c(5:9,10,13,16,18,20,21,24), 
                         "change.deaths"]),
                       -1 * sum(l$cause_sum[
                         c(5:9,10,16,18,20,21,24), 
                         "coi"]) / 10 ^ 9, l$co2[2, 8]),
        stringsAsFactors = F
      )
    
    STab1$Baseline <- as.numeric(STab1$Baseline) 
    STab1$Scenario <- as.numeric(STab1$Scenario) 
#    print(STab1)
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Recall that if this output is a
    # table we need in-text citations.
    # Therefore, we check to see if the
    # output data.frames need to be
    # adjusted to include our citation
    # notation "XX" (to be resolved using
    # regular expressions, see
    # `base::grepl`).
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    if(l$is_formatted == T){
      STab1$Item[1] <- "Active Travel Time (min/p/w)XX"
      STab1$Item[4] <- "Carbon Emissions (MMTY)XX"
    }

    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Table 2 - Per capita mean weekly
    # active travel times (minutes)
#    print(l$at_sat_wide)
    STab2 <- reshape(l$at_sat_wide[17,4:9],
                     varying = c("Baseline.Walk",
                                 "Scenario.Walk",
                                 "Baseline.Bike",
                                 "Scenario.Bike",
                                 "Baseline.Total",
                                 "Scenario.Total"), 
                     v.name= c("Baseline","Scenario"),
                     timevar= "Mode",
                     times = c("Walk","Bike","Total"),
                     new.row.names = 1:3,
                     ids = NULL,
                     direction="long")
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Table 3 - Per capita mean weekly
    # travel distance (miles) by mode
    STab3 <-  l$bs_distance_mode[1,2:4]
    STab3[1, 1:3] <- c("Active",
                       sum(l$bs_distance_mode[c(1,8),3]), 
                       sum(l$bs_distance_mode[c(1,8),4]))
    STab3[2, 1:3] <- c("Car",
                       sum(l$bs_distance_mode[3:4, 3]), 
                       sum(l$bs_distance_mode[3:4, 4]))
    STab3[3, 1:3] <- c("Transit", 
                       sum(l$bs_distance_mode[c(2,6), 3]), 
                       sum(l$bs_distance_mode[c(2,6), 4]))
    STab3[4, 1:3] <- c("Total (incl. Truck & Motorcycle)",
                       sum(l$bs_distance_mode[1:8, 3]),
                       sum(l$bs_distance_mode[1:8, 4]))
    
    # change back to double.
    STab3$Baseline <- as.numeric(STab3$Baseline)
    STab3$Scenario <- as.numeric(STab3$Scenario)
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Table 4 - Annual Change in the
    # Burden of Disease by Health Pathway
    
    # drop All causes from cause_sum
    cause_pathway <- l$cause_sum[l$cause_sum$Cause!="All Causes",]
    
    STab4 <- data.frame(
      "Pathway" = c("Physical Activity", 
                    "Air Pollution", 
                    "Road Traffic Injuries", 
                    "Total"),
      "PAF Deaths" = c(
        -100 * 
          sum(cause_pathway[cause_pathway$Pathway=="PA","change.deaths"])/
          sum(cause_pathway[cause_pathway$Pathway=="PA","bd.deaths"]),
        -100 *
          sum(cause_pathway[cause_pathway$Pathway=="PM","change.daly"])/
          sum(cause_pathway[cause_pathway$Pathway=="PM","bd.daly"]),
        -100 *
          sum(cause_pathway[cause_pathway$Pathway=="RTI","change.daly"])/
          sum(cause_pathway[cause_pathway$Pathway=="RTI","bd.daly"]),
        -100 *
          sum(cause_pathway[cause_pathway$Pathway %in% 
                              c("PA","PM","RTI"),"change.deaths"])/
          sum(cause_pathway[cause_pathway$Pathway %in% 
                              c("PA","PM","RTI"),"bd.deaths"])
      ),
      "Deaths Avoided" = c(
        -1 * 
          sum(cause_pathway[cause_pathway$Pathway=="PA","change.deaths"]), 
        -1 * 
          sum(cause_pathway[cause_pathway$Pathway=="PM","change.deaths"]),  
        -1 * 
          sum(cause_pathway[cause_pathway$Pathway=="RTI","change.deaths"]),
        -1 * 
          sum(cause_pathway[cause_pathway$Pathway %in% 
                              c("PA","PM","RTI"),"change.deaths"])
      ),     
      "PAF Dalys" = c(
        -100 * 
          sum(cause_pathway[cause_pathway$Pathway=="PA","change.daly"])/
          sum(cause_pathway[cause_pathway$Pathway=="PA","bd.daly"]),
        -100 *
          sum(cause_pathway[cause_pathway$Pathway=="PM","change.daly"])/
          sum(cause_pathway[cause_pathway$Pathway=="PM","bd.daly"]),
        -100 * 
          sum(cause_pathway[cause_pathway$Pathway=="RTI","change.daly"])/
          sum(cause_pathway[cause_pathway$Pathway=="RTI","bd.daly"]),
        -100 * 
          sum(cause_pathway[cause_pathway$Pathway %in% 
                              c("PA","PM","RTI"), "change.daly"])/
          sum(cause_pathway[cause_pathway$Pathway %in% 
                              c("PA","PM","RTI"), "bd.daly"])
      ),
      "Dalys Avoided" =  c(
        -1 * 
          sum(cause_pathway[cause_pathway$Pathway=="PA","change.daly"]),
        -1 * 
          sum(cause_pathway[cause_pathway$Pathway=="PM","change.daly"]),  
        -1 * 
          sum(cause_pathway[cause_pathway$Pathway=="RTI","change.daly"]),                 
        -1 * 
          sum(cause_pathway[cause_pathway$Pathway %in% 
                              c("PA","PM","RTI"),"change.daly"])
      ),
      stringsAsFactors = F
    )
    
    if(l$is_formatted == T){
      # NOTE: if in-text citation is required, modify cell in:
      # ithim_tool_strings.csv > rp.st_colspans
      # with XX
      
      # names(STab4)[2] <- "PAFXX Deaths"
      # names(STab4)[4] <- "PAF DALYsXX"
    }
#   print(STab4) 
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Table 5 - Annual Change in the Value
    # of Health Benefits
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    STab5 <- data.frame(
      "Method" = c("Cost of Illness",
                   "Value of a Statistical Life"),
      "Dollars" = c(-1 * sum(l$cause_sum[c(5:9,10,16,18,20,21,24),
                                         "coi"] / 10 ^ 9),
                    -1 * sum(l$cause_sum[c(5:9,10,16,18,20,21,24),
                                         "vsl"] / 10 ^ 9)),
      stringsAsFactors = F
    )
#    print(STab5)  
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Table 6 - Aggregate and Per Capita
    # Car Carbon Emissions
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    STab6 <- data.frame(
      "CO2 Emissions" = c("Aggregate (Million Metric Tons)", 
                          "Per Capita (Metric Tons)"), 
      check.names = F,
      "Baseline" = c(l$co2[2,7], 10^6*l$co2[2,7]/l$co2[2,6]),
      "Scenario" = c(l$co2[2,8], 10^6*l$co2[2,8]/l$co2[2,6]),
      stringsAsFactors = F
    )
 
#  print(STab6) 
  
#  dif <- STab6[1,3] - STab6[1,2] 
#  print(dif)
  
    # list to return
    core <- list(
      STab1=STab1,
      STab2=STab2,
      STab3=STab3,
      STab4=STab4,
      STab5=STab5,
      STab6=STab6
    )
    
    
  } else if(l$detail=="Medium"){
    # ..Medium ----
    
    # # retrieve template titles for summary tables
    # titles <- d$txt$Content[which(d$txt$Element=="rp.mttllist")]
    # 
    # # separate titles by semi-colon
    # titles <- strsplit(titles, ";")[[1]]
    # 
    # # Error checking.
    # if(length(titles) != 4) stop(
    #   "Error fn_dataframer: medium titles not right length"
    # )
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Table 0. Conditional for Multiples with transit
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Table 1. Per Capita Mean Active Travel Time by Age and Gender
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Age-specific total mean time is
    # population-weighted average of males
    # and females
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    MTab1 <- merge(l$at_sat_wide,
                   l$age_sex_region_year, 
                   by=c("Age","Sex"))
    
    MTab1 <- MTab1[,c("Age", 
                      "Sex", 
                      "Baseline.Total",
                      "Scenario.Total", 
                      "Population")]
    
    MTab1 <- MTab1[order(MTab1$Sex, 
                         MTab1$Age),]
    
    names(MTab1)[3:4] <- c("Baseline", "Scenario")
    
    MTab1 <- cbind(MTab1[1:8,c("Age",
                               "Sex",
                               "Population", 
                               "Baseline",
                               "Scenario")], 
                   MTab1[9:16,c("Population",
                                "Baseline",
                                "Scenario")])
    
    names(MTab1)[3:8] <- c("Male.Population", 
                           "Male.Baseline", 
                           "Male.Scenario", 
                           "Female.Population",
                           "Female.Baseline", 
                           "Female.Scenario")
    
    # Baseline
    MTab1$Baseline <- (MTab1$Male.Baseline*
                         MTab1$Male.Population + 
                         MTab1$Female.Baseline*
                         MTab1$Female.Population)/
      (MTab1$Male.Population + 
         MTab1$Female.Population)
    
    # Scenario
    MTab1$Scenario <- (MTab1$Male.Scenario*
                         MTab1$Male.Population + 
                         MTab1$Female.Scenario*
                         MTab1$Female.Population)/
      (MTab1$Male.Population + 
         MTab1$Female.Population)
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Gender-specific mean active travel
    # time is population weighted average
    # of age-specific gender strata
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    
    MTab1[9,9] <- sum(
      MTab1$Male.Baseline*
        MTab1$Male.Population)/
      sum(MTab1[1:8, c("Male.Population")]
      )
    
    MTab1[9,10] <- sum(
      MTab1$Male.Scenario*
        MTab1$Male.Population,na.rm = T)/
      sum(MTab1[1:8, c("Male.Population")]
      )
    
    MTab1[9,1] <- "Male"
    
    MTab1[10,9] <- sum(
      MTab1$Female.Baseline*
        MTab1$Female.Population, na.rm=T)/
      sum(MTab1[1:8, c("Female.Population")]
      )
    
    MTab1[10,10] <- sum(
      MTab1$Female.Scenario*
        MTab1$Female.Population, na.rm = T)/
      sum(MTab1[1:8, c("Female.Population")]
      )
    
    MTab1[10,1] <- "Female"
    
    MTab1 <- MTab1[,c("Age","Baseline", "Scenario")]
    
    names(MTab1)[1] <- "Age_Gender"
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Table 2. Per Capita Mean Distances by Mode
    MTab2 <- l$bs_distance_mode[2:4]
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Table 3. Annaul Percent and Number of Deaths Averted


    print(l$cause_sum)
    
    MTab3 <- l$cause_sum[c(5:9,10,13,16,18,20,21,24),  
                          c(1,8,16,12)]
# print(MTab3)
    
    
    MTab3[3:4] <- -1*MTab3[,c(3,4)] 
    
    MTab3[3] <- 100*MTab3[3] 
    
    MTab3[13,2] <- sum(MTab3[MTab3$Cause %in% 
                               c("Hypertensive Heart Disease",
                                 "Ischemic Heart Disease", 
                                 "Stroke",
                                 "Inflammatory Heart Disease"),
                             "bd.deaths"])
    
    MTab3[13,4] <- sum(MTab3[MTab3$Cause %in% 
                               c("Hypertensive Heart Disease",
                                 "Ischemic Heart Disease", 
                                 "Stroke",
                                 "Inflammatory Heart Disease"),
                             "change.deaths"])
    
    MTab3[13,1] <- "Heart Disease and Stroke"
    
    # Correction (from previous version) to make into percent
    MTab3[13,3] <- 100 * MTab3[13,4]/MTab3[13,2]
    
    MTab3 <- MTab3[c(1:5,9:11,13), ]
    
    MTab3 <- MTab3[order(-MTab3$change.deaths), ]
    
    MTab3[10,2] <- sum(MTab3[1:9,"bd.deaths"])
    
    MTab3[10,4] <- sum(MTab3[1:9,"change.deaths"])
    
    MTab3[10,3] <- 100*MTab3[10,4]/MTab3[10,2]
    
    MTab3 <- MTab3[,c(1,3,4)]
    
    MTab3[10,1] <- "Total"
    
    names(MTab3)[2:3] <- c("PAF %","Deaths")
  
#    print(MTab3)
      
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Tab 4. Costs by Cause
    MTab4 <- l$cause_sum[c(5:9,10,16,18,20,21,24),
                         c(20,23,24)]
    
    MTab4[2:3] <- -1*MTab4[,c(2,3)]/10^6 
    
    MTab4[12,2] <- sum(MTab4[MTab4$SpecificCause %in% 
                               c("Heart Disease"),
                             "coi"])
    
    MTab4[12,3] <- sum(MTab4[MTab4$SpecificCause %in% 
                               c("Heart Disease"),
                             "vsl"])
    
    MTab4[12,1] <- "Heart Disease"
    
    MTab4 <- MTab4[c(1:5,8:12), ]
    
    MTab4 <- MTab4[order(-MTab4$vsl), ]
    
    MTab4[11,2] <- sum(MTab4[1:10,"coi"])
    
    MTab4[11,3] <- sum(MTab4[1:10,"vsl"])
    
    MTab4[11,1] <- "Total"
    
    names(MTab4)[1:3] <- c("Cause", "COI","VSL")
    
    if(l$is_formatted == T){
      MTab4[9,1] <- paste0(MTab4[9,1], "XX") # add citation
      names(MTab4)[2:3] <- c("COIXX","VSLXX")
    }
    
    # list to return
    core <- list(
      MTab1=MTab1,
      MTab2=MTab2,
      MTab3=MTab3,
      MTab4=MTab4
    )
    
    
  } else if(l$detail=="High"){
    # ..High ----
    
    # TODO this is whole high detail is messy, clean.
    # # retrieve template titles for summary tables
    # titles <- d$txt$Content[which(d$txt$Element=="rp.httllist")]
    # 
    # # separate titles by semi-colon
    # titles <- strsplit(titles, ";")[[1]]
    # 
    # # Error checking.
    # if(length(titles) != 5) stop(
    #   "Error fn_dataframer: high titles not right length"
    # )
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Table 1. Per Capita Weekly Mean Active Travel Time by Age and Gender
    HTab1 <- l$at_sat_wide[-1]
    # merge with PA_PAF_IHD to pick up age-sex population, 
    # including both sexes and all ages 
    HTab1$Sex[HTab1$Sex == 1] <- "M"
    HTab1$Sex[HTab1$Sex == 2] <- "F"
    HTab1 <-
      merge(HTab1, l$PA_PAF_IHD[, c("Age", "Sex", "Population")])
    HTab1$Sex[HTab1$Sex == "M"] <- "Male"
    HTab1$Sex[HTab1$Sex == "F"] <- "Female"
    names(HTab1)[2] <- "Age.Group"
    
    HTab1 <-
      HTab1[, c(
        "Sex",
        "Age.Group",
        "Population",
        "Baseline.Walk",
        "Baseline.Bike",
        "Baseline.Total",
        "Scenario.Walk",
        "Scenario.Bike",
        "Scenario.Total"
      )]
    
    # Reoreder File
    HTab1 <- rbind(HTab1[10:17, ], HTab1[2:9, ], HTab1[1:1, ])
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Table 2. Annual Change in the Burden of Disease by Cause and Pathway
    HTab2 <- l$cause_sum[,c(1,2,12:19)]
    HTab2 <- HTab2[order(HTab2$Pathway,
                         HTab2$change.deaths),]
    HTab2[3:10] <- -1*HTab2[3:10]
    HTab2[7:10] <- 100*HTab2[7:10]
    names(HTab2)[1] <- "Disease.Injury.Classification"
 
#  print(HTab2)      
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Table 3. Annual Change in Burden of Disease, Specific Cause
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    
    if(!is.null(l$specific_disease)) {
      l$specific_disease_title <- F
      HTab3 <- fn_specific_disease(l)$specific_disease_df
      # if specific_disease, rename table.
      table_str$title[3] <- sub("Cause", 
                                l$specific_disease[1, "ui_select"], 
                                table_str$title[3])
      # garbage collection
      l$specific_disease_df <- NULL
    } else {
      # if no specific_disease selected, remove third title.
      table_str <- table_str[c(1,2,4,5),]
    }
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Table 4.Number of Fatal and Serious Injuries by Victim Mode
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    HTab4 <- l$rti_RR_mode[,c(2,3,6:10)]
    HTab4_split <- split(HTab4, HTab4$Severity)
    HTab4_temp <- cbind(HTab4_split$Fatal, HTab4_split$Serious)
    HTab4_temp <- HTab4_temp[,c(2,3,10,4,11,7,14)]
    names(HTab4_temp)[1:7] <- c("Mode",
                                "Baseline.Fatal", 
                                "Baseline.Serious",
                                "Scenario.Fatal", 
                                "Scenario.Serious",
                                "RR.Fatal",
                                "RR.Serious" )
    
    HTab4_temp$Baseline.Total <- HTab4_temp$Baseline.Fatal + 
      HTab4_temp$Baseline.Serious
    HTab4_temp$Scenario.Total <- HTab4_temp$Scenario.Fatal + 
      HTab4_temp$Scenario.Serious
    
    HTab4 <- HTab4_temp[,c("Mode",
                           "Baseline.Total", 
                           "Baseline.Fatal", 
                           "Baseline.Serious", 
                           "Scenario.Total", 
                           "Scenario.Fatal", 
                           "Scenario.Serious",
                           "RR.Fatal",
                           "RR.Serious" )]
    
    # Population adjustment
    # Use population adjustment from 2010 baseline to year of interest
    HTab4[, 2:8] <- HTab4[, 2:8] * l$pop_adjust
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Table 5. Rate (per 109 Miles) of 
    # Fatal and Serious Injuries by Victim 
    # Mode
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    HTab5 <- cbind(HTab4_split$Fatal[,c(2,5:6)],
                   HTab4_split$Serious[,c(5:6)]) 
    
    names(HTab5)[1:5] <- c("Mode", 
                           "Baseline.Fatal",
                           "Baseline.Serious", 
                           "Scenario.Fatal",
                           "Scenario.Serious")
    
    # list to return
    if(is.null(l$specific_disease)) {
      core <- list(
        HTab1=HTab1,
        HTab2=HTab2,
        HTab4=HTab4,
        HTab5=HTab5
      )
    } else {
      core <- list(
        HTab1=HTab1,
        HTab2=HTab2,
        HTab3=HTab3,
        HTab4=HTab4,
        HTab5=HTab5
      )
    }
  } else {
    # If neither Summary, Medium, or High:
    # core <- list()
    stop("Error: fn_dataframer missing tables.")
  }
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Add the attributes of df_id and df_name to each table in core.
  core <- lapply(seq_along(core), function(i){
    structure(core[[i]], 
              df_id=table_str$id[i],
              df_name=table_str$title[i]
    )
  })

  l$df_list <- core
  l  # return
}

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# FUNCTION: Table Production Manager
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#' Creates a list of HTML tables.
#' 
#' @param l is the list object produced by run(), 
#' but with instructions appended for the construction of tables.
#' @return the same list object as the param, but with HTML tables and HTML h3 titles appended.
fn_tableManager <- function(l){

    # retrieve Geography and Scenario Name.
    # geo <- l$fGeography
    # scenario <- l$scenario$name
    # yr <- l$fYear

    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # SECTION: Summary + Table
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # if(l$detail=="Summary"){
    #   
    #   # retrieve spanning headers
    #   cs <- list()  # default value for colspans.
    #   try(cs <- d$txt$Content[d$txt$Element=="rp.st_colspans"])
    # 
    # }  # end of Summary + Table
    # 
    # # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # # SECTION: Medium + Table
    # # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # if(l$detail=="Medium"){
    #   
    #   # retrieve spanning headers
    #   cs <- list()  # default value for colspans.
    #   try(cs <- d$txt$Content[d$txt$Element=="rp.mt_colspans"])
    #   
    # }  # End of Medium + Table
    # 
    # if(l$detail=="High"){
    # 
    #   # in its respective row in ithim_tool_strings.csv
    #   # if(is.null(l$specific_disease)) titles <- titles[c(1:2,4:5)]
    #   # TODO shouldn't this be !is.null?
    #   
    #   # retrieve spanning headers
    #   cs <- list()  # default value for colspans.
    #   # TODO determine why this try() is here... I don't think its necessary.
    #   try(cs <- d$txt$Content[d$txt$Element=="rp.ht_colspans"])
    #   
    # }  # End of High + Table
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # append spanning column headers to l
    # l$cs <- fn_colspans(cs)
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # create data.frames in order to later make HTML tables.
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # In order to check if in-text
    # citations will be appended to
    # data.frames, fn_dataframer needs to
    # know if it should be formatted,
    # hence the addition of "is_formatted"
    # to `l`.
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # l$is_formatted <- T
    l <- fn_dataframer(l)
    l$is_formatted <- F
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # lo for sig-figs formatting.
    # Note: lo=0 is an expedient; we can modify this later to adjust
    # sig figs for each column if we supply a list or data.frame.
    l$sigfigs <- 1
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Formate data.frame columns (i.e. turn into character cols)
    l <- fn_formattr_df(l)
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Create HTML tables (brings together title roots, colspans, core)
    l <- fn_tableTagger(l)
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Note about Titles.
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # There are two sets of titles, one is
    # for creating the tables themselves
    # (specifically, to match with any
    # spanning column headers if they are
    # present). This set of titles is
    # embedded into the data.frames
    # created in fn_dataframer. The second
    # set of titles are meant to be used
    # for the actual HTML h4 tags. This
    # second set is what you see on the
    # webpage.
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    
    # # Obtain titles of data.frames from df_list (of fn_dataframer)
    # titles <- sapply(l$df_list, function(x){
    #   attributes(x)$df_name
    # })
    
    # # Append geography and scenario info to titles.
    # html_titles <- unname(sapply(titles,
    #                              function(nm) gsub(pattern="\\s{2,}",
    #                                                replacement=" ",
    #                                                x=paste0(nm,
    #                                                         geo,
    #                                                         ", ",
    #                                                         scenario,
    #                                                         ", ",
    #                                                         yr
    #                                                ))))
    # 
    # # Prepend titles with a number sequence.
    # html_titles <- unname(sapply(seq_along(html_titles), function(i){
    #   paste0(i, ". ", html_titles[i])
    # }))
    # 
    # # Create HTML h4 titles
    # html_titles <- lapply(html_titles, function(x){
    #   tags$h4(x, class="ithimTable_title")
    # })
    # 
    # Append HTML Titles
    # l$titles <- html_titles
    
    # Garbage Collection
    # l$cs <- NULL
    l$sigfigs <- NULL
    # Note, we don't remove df_list, as it will be utilized in download CSV
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # return
    l
}

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# FUNCTION GROUP ----
# The below functions create ggplots
# Primary: fn_plotter
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# FUNCTION: Plotter using ggplot2
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#' Plot individual plot using ggplot2
#' 
#' @param df is a data.frame created by fn_graphManager
#' @return a ggplot2 object.
fn_plotter <- function(df){
  # Note:
  # Equis is Spanish for "x"
  # igriega is Spanish for "y"

  # Error checking
  if(is.null(df)) stop("Error fn_plotter: df is null.")
  
  # Break up text with underscores in it.
  for(x in seq_along(df)){
    if(T %in% grepl("_", df$ScenarioName, perl=T)) {
      df$ScenarioName <- gsub("_", " ", df$ScenarioName)
    }
  }
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Dynamically retrieve columns to pass to ggplot...
  # x (gets name of first column that is character & not ScenarioName)
  equis <- names(which(!(names(df) %in% "ScenarioName") & 
                         sapply(df, function(x) is.character(x))))[1]
  lab_equis <- gsub("\\.", " ", equis, perl=T)  # replace periods in label name.
  
  # y (gets name of first column that is double)
  igriega <- names(df[sapply(df,
                             function(x) is.double(x))])[1]
  lab_igriega <- gsub("\\.", 
                      " ", 
                      igriega, 
                      perl=T)  # replace periods in label name.
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # plot
  if(attr(df,"plot_type")=="bar"){
    # Plot - Bar ----
    bar_labs <- names(df)[1]  # ignore RStudio warning about non-use!
    # breakup tick labels for geom_bar, note: assumes label is in first column!
    # TODO resolve tick-label size for crowded bar charts.
    df[1] <- unname(sapply(df[,1], function(x) {
      # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      # Note: when barcharts exceed a
      # certain number of rows, it gets too
      # crowded for all the axis-tick-labels
      # to fit if they each get multipline
      # lines. Eight is kind of arbitrary,
      # but it seems to work.
      # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      if(nrow(df) > 8) return(x)
      
      # split up cell's text by whitespace
      x2 <- strsplit(x,
                    "\\s",
                    perl=T)[[1]]
      if(length(x2)==1) return(x)
      string_clusters <- NULL
      temp <- NULL
      # loop through each piece of text and
      # break up by segments of 5 characters
      for(i in seq_along(x2)){
        if(is.null(temp)){
          temp <- x2[i]
        } else {
          temp <- paste(temp, x2[i])
        }

        if(nchar(temp) <= 5 & i < length(x2)) {
          next()
        } else {
          if(is.null(string_clusters)) {
            string_clusters <- temp
          }  else {
            string_clusters <- c(string_clusters, temp)
          }
          temp <- NULL  # reset
        }
      }
      paste(string_clusters, collapse="\n")  # return
      }))
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # now create plot.
    p <- ggplot(data=df,
                # use aes_string to pass name of column in quotes as arguments.
                aes_string(x=paste0("reorder(`",  # reorder by size of y
                                    equis,
                                    "`, `",
                                    igriega,
                                    "`)"),
                y=igriega,
                label="bar_labs",
                fill="ScenarioName")) +
      geom_bar(data=df,
               stat="identity",
               position=position_dodge(width=0.7),
               width=0.7,
               show.legend = T) +
      scale_fill_manual("Legend", 
                        values = c("Baseline" = colores[2], 
                                   "Scenario" = otros_colores[5]),
                        guide = guide_legend(reverse = TRUE)) +
      theme(panel.grid.major.y = element_blank(),
            panel.grid.major.x = element_line(size=.25, 
                                              color=colores[5]),
            axis.title.x = element_text(size=20,
                                        color=colores[1],
                                        margin=margin(1,0,0,0,"lines")),
            axis.title.y = element_text(size=20,
                                        color=colores[1],
                                        margin=margin(0,1,0,0,"lines"))
            ) +
      xlab(lab_equis) +
      ylab(lab_igriega) +
      coord_flip()
    
  } else if (attr(df,"plot_type")=="line"){
    # Plot - Line ----
    # saveRDS(df, paste0("line",Sys.time()))
    p <- ggplot(data=df, 
                aes_string(x=paste(equis), 
                           y=paste(igriega), 
                           group="ScenarioName", 
                           color="ScenarioName")
    ) +
      geom_line(aes_string(linetype = "ScenarioName"),
                stat = "identity", 
                size=1.5,
                show.legend = T) +
      scale_linetype_manual(values=c("solid", "solid", "dashed","dashed")) +
      scale_color_manual(values=c(colores[2], 
                                  otros_colores[5],
                                  colores[2], 
                                  otros_colores[5])) +
      theme(panel.grid.major.x = element_blank(),
            panel.grid.major.y = element_line(size=.25, 
                                              color=colores[5]), 
            axis.text.x = element_text(angle=0,
                                       margin=margin(0.5,1,0,0,"lines")),
            axis.title.x = element_text(size=20,
                                        color=colores[1],
                                        margin=margin(1,0,0,0,"lines")),
            axis.title.y = element_text(size=20,
                                        color=colores[1],
                                        margin=margin(0,1,0,0,"lines"))
      ) +
      # adjust size of legend key:
      guides(color = guide_legend(override.aes = list(size = 0.5))) +
      xlab(lab_equis) +
      ylab(lab_igriega)
  }
  # add common theme of plots
  p <- p +
    theme(legend.title=element_blank(),  # legend title
          legend.key=element_blank(),  # key background
          axis.title.x = element_text(vjust=-2),
          panel.grid.minor = element_blank(),
          panel.border = element_rect(size=1, 
                                      color=colores[5], 
                                      fill=NA),
          panel.background = element_blank(),
          plot.margin=unit(c(2,1,2,1), "lines"),
          axis.text = element_text(size=12, 
                                   color=colores[5]),
          axis.ticks = element_blank()
    )
  
  p  # return
}

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# FUNCTION: GGPlot Data.frame Maker
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#' Create Graph/Figure data.frames.
#'
#' @param l is a list from run() with visual and detail elements added.
#' @return a list of data.frames to be plotted.
fn_graphManager <- function(l){
  # TODO fix fn_dataframer so it creates named elements.

  
  if(l$detail=="High") {
    if(is.null(l$specific_disease)) 
      stop("Error: No specific disease selected.")
  }
  
  # retrieve Geography and Scenario Name.
  geo <- l$fGeography
  # TODO find alternative method to do the following:
  # Temporary fix, to append "County" to counties.
  if(!(geo %in% c(
    "California",
    "Sacramento Area",
    "San Diego County",
    "San Joaquin Valley",
    "SF Bay Area",
    "Southern California"
  ))){
   geo <- paste(geo, "County")
 
  }
  
  scenario <- l$scenario$name
  yr <- l$fYear
  
  # temporarily change visual to table in order to obtain data.frames.
  # l$visual <- "Table"
  df_list <- fn_dataframer(l)$df_list  # obtain data.frames

  titles <- sapply(df_list, function(x) {attributes(x)$df_name})
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Summary Detail Plot
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  if(l$detail == "Summary"){
    # Graph DF - Summary ----
    # # retrieve titles
    # titles <- d$txt$Content[which(d$txt$Element=="rp.sttllist")]
    # 
    # # separate titles by semi-colon
    # titles <- strsplit(titles, ";")[[1]]
    # 
    # subset titles for graphs we want.
    titles <- titles[c(2:length(titles))]
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Create data.frames for figures.
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Figure 2 - Per capita mean weekly active travel times (minutes)
    SFig2 <- reshape(df_list[[2]],
                     varying= c("Baseline","Scenario"),
                     v.name="Minutes",
                     timevar="ScenarioName",
                     times = c("Baseline","Scenario"),
                     new.row.names = 1:6,
                     ids = NULL,
                     direction="long")
    
    attr(SFig2, "plot_type") <- "bar"  # assign plot type: bar or line
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Fig 3 - Per capita mean weekly travel distance (miles) by mode
    SFig3 <- reshape(df_list[[3]][1:3,],
                     varying= c("Baseline","Scenario"),
                     v.name="Miles",
                     timevar="ScenarioName",
                     times = c("Baseline","Scenario"),
                     new.row.names = 1:6,
                     ids = NULL,
                     direction="long")
    
    attr(SFig3, "plot_type") <- "bar"  # assign plot type: bar or line
    
    # Correct column (and thus x-axis label)
    if(l$td_unit == "Kilometers")
      names(SFig3)[which(names(SFig3)=="Miles")] <- "Kilometers"
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Fig 4. Annual Change in the Burden of Disease by Health Pathway
    SFig4 <- df_list[[4]][,c(1,3)]
    SFig4$ScenarioName <- "Scenario"
    SFig4 <-SFig4[,c("Pathway","ScenarioName","Deaths.Avoided")]
    
    attr(SFig4, "plot_type") <- "bar"  # assign plot type: bar or line
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Fig 5. Annual Change in the Value of Health Benefits
    SFig5 <- df_list[[5]]
    SFig5$ScenarioName <- "Scenario"
    SFig5 <-SFig5[,c("Method","ScenarioName","Dollars")]
    
    attr(SFig5, "plot_type") <- "bar"  # assign plot type: bar or line
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Fig 6. Aggregate and Per Capita Car Carbon Emissions
    SFig6 <- reshape(df_list[[6]],
                     varying= c("Baseline","Scenario"),
                     v.name="Tons",
                     timevar="ScenarioName",
                     times = c("Baseline","Scenario"),
                     new.row.names = 1:6,
                     ids = NULL,
                     direction="long")
    
    attr(SFig6, "plot_type") <- "bar"  # assign plot type: bar or line
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    figures <- list(
      SFig2,
      SFig3,
      SFig4,
      SFig5,
      SFig6
    )
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Medium Detail Plot
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  } else if(l$detail == "Medium"){
    # Graph DF - Medium ----
    # # retrieve titles.
    # titles <- d$txt$Content[which(d$txt$Element=="rp.mttllist")]
    # 
    # # separate titles by semi-colon
    # titles <- strsplit(titles, ";")[[1]]
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Fig 1. Per Capita Mean Active Travel Time by Age
    # Gender not shown on graph
    MFig1 <- df_list[[1]][1:8,c("Age_Gender","Baseline")]
    MFig1[9:16,] <- df_list[[1]][1:8,c(1,3)]
    MFig1$ScenarioName <- "Baseline"
    MFig1[9:16,3] <- "Scenario"
    names(MFig1)[1:2] <- c("Age","Minutes")
    MFig1 <- MFig1[,c("Age", "ScenarioName", "Minutes")]
    
    attr(MFig1, "plot_type") <- "line"  # assign plot type: bar or line
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Fig 2. Per Capita Mean Distances by Mode
    MFig2 <- reshape(df_list[[2]],
                     varying= c("Baseline","Scenario"),
                     v.name="Miles",
                     timevar="ScenarioName",
                     times = c("Baseline","Scenario"),
                     new.row.names = 1:16,
                     ids = NULL,
                     direction="long")
    
    attr(MFig2, "plot_type") <- "bar"  # assign plot type: bar or line
    
    # Correct column (and thus x-axis label)
    if(l$td_unit == "Kilometers")
      names(MFig2)[which(names(MFig2)=="Miles")] <- "Kilometers"
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Fig 3. Annaul Percent and Number of Deaths Averted
    MFig3 <- df_list[[3]][,c(1,3)]
    MFig3$ScenarioName <- "Scenario"
    MFig3 <- MFig3[,c("Cause","ScenarioName","Deaths")]
    
    attr(MFig3, "plot_type") <- "bar"  # assign plot type: bar or line
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Fig 4. VSL Costs by Cause
    
    MFig4 <- df_list[[4]][,c("Cause","VSL")]
    MFig4$ScenarioName <- "Scenario"
    names(MFig4)[2:3] <- c("Dollars","ScenarioName")
    MFig4 <- MFig4[,c("Cause","ScenarioName","Dollars")]
    
    attr(MFig4, "plot_type") <- "bar"  # assign plot type: bar or line
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    figures <- list(
      MFig1,
      MFig2,
      MFig3,
      MFig4
    ) 
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # High Detail Plot
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  } else if(l$detail == "High"){
    # Graph DF - High ----
    # # retrieve titles.
    # titles <- d$txt$Content[which(d$txt$Element=="rp.httllist")]
    # 
    # # separate titles by semi-colon
    # titles <- strsplit(titles, ";")[[1]]
    # 
    # # subset titles for graphs we want.
    # titles <- titles[c(1:4)]
    # 
    # # Graph 3's Cause-Specific Change in Burden of Disease by Age and Sex
    # titles[3] <- sub("Cause", l$specific_disease[1, "Cause"], titles[3])
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Fig 1. Per Capita Weekly Mean Active Travel Time by Age and Gender
    HFig1 <- df_list[[1]][1:16,c("Sex","Age.Group","Baseline.Total")]
    HFig1[17:32,c(1:3)] <- df_list[[1]][1:16,
                                        c("Sex","Age.Group","Scenario.Total")]
    if(nrow(HFig1) > 32)
      stop("ERROR: In creating figure df, HFig1 was too long.")
    HFig1$ScenarioName <- sapply(seq_len(nrow(HFig1)), function(x){
      if(x < 17)
        paste0(HFig1$Sex[x],"_Baseline")
      else
        paste0(HFig1$Sex[x],"_Scenario")
    })
    names(HFig1)[3] <- "Minutes"
    HFig1 <- HFig1[,c("Age.Group","ScenarioName","Minutes")]
    rownames(HFig1) <- NULL  # remove row names.
    attr(HFig1, "plot_type") <- "line"  # assign plot type: bar or line
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Figure 2. Annual Change in DALYs by Cause and Pathway
    HFig2 <- df_list[[2]][c(3,6:12,15,17,19,21),c(1,2,6)]
    HFig2$Cause <- paste0(HFig2$Cause," (",HFig2$Pathway,")")
    names(HFig2)[2:3] <- c("ScenarioName", "DALYs.Averted")
    HFig2$ScenarioName <- "Scenario"
    rownames(HFig2) <- NULL
    attr(HFig2, "plot_type") <- "bar"  # assign plot type: bar or line
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Figure 3.
    # create Figures as a new dataframe with cause METS, PAF, Change in BD  
    cause_temp_long <- df_list[[3]][1:16,c("Age","Sex","DALY")]
    names(cause_temp_long)[2] <- "ScenarioName"
    cause_temp_long$ScenarioName[cause_temp_long$ScenarioName == "M"] <- 
      "Male"
    cause_temp_long$ScenarioName[cause_temp_long$ScenarioName == "F"] <- 
      "Female"
    HFig3 <- cause_temp_long[,c("Age","ScenarioName","DALY")]
    rownames(HFig3) <- NULL
    attr(HFig3, "plot_type") <- "line"  # assign plot type: bar or line
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Figure 4.Number of Fatal Injuries by Victim Mode
    HFig4 <- df_list[[4]][,c(1,3)]
    HFig4[8:14,] <- df_list[[4]][,c(1,6)]
    HFig4$ScenarioName <- "Baseline"
    HFig4[8:14,c("ScenarioName")] <- "Scenario"
    names(HFig4)[2] <- "Fatal.Injuries"
    HFig4 <- HFig4[,c("Mode","ScenarioName","Fatal.Injuries")]
    rownames(HFig4) <- NULL
    attr(HFig4, "plot_type") <- "bar"  # assign plot type: bar or line
    
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    figures <- list(
      HFig1,
      HFig2,
      HFig3,
      HFig4
    ) 
    
  }
  
  # print("graphframer titles")
  # print(titles)
  
  # add breadcrumbs to title.
  titles <- unname(sapply(titles,
                          function(nm) gsub(pattern="\\s{2,}",
                                            replacement=" ",
                                            x=paste0(nm,
                                                     ", ",
                                                     geo,
                                                     ", ",
                                                     scenario,
                                                     ", ",
                                                     yr))))
  
  # number the titles.
  titles <- unname(sapply(seq_along(titles), function(i){
    paste0(i, ". ", titles[i])
  }))
  
  # create HTML for titles
  l$titles <- lapply(titles, function(x){
    tags$h4(x, class="ithimTable_title")
  })
  
  l$objects <- figures
  
  # return
  l
}

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# FUNCTION GROUP ----
# The below functions create the report
# Primary: fn_reporter
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# FUNCTION: Report Calculations Data.frame Maker
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#' Creates data for both Summary and Infographic Reports.
#'
#' @param l is a list with output of run()
#' @return l is a list with report_values added.
fn_report_calc <- function(l){
  df_list <- fn_dataframer(l)$df_list
  
  # retrieve table of possible report text.
  rt <- d$report_template
  
  # create character vector for each row's text.
  text <- c()
  
  # create list of values for each row.
  val <- sapply(1:8, function(x) NULL)
  
  # create list of icons
  icons <- rt$icon
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Row 1 - Text only
  row <- 1
  val[[row]] <- ""
  text <- c(text, rt[row, "alt1"])
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Row 2 - Short Car Trips & Active Travel
  row <- 2
  tmp1 <- ceiling(df_list[[1]][1, 2])
  tmp2 <- ceiling(df_list[[1]][1, 3])
  
  val[[row]] <- list(
    Scenario = l$scenario$name,
    Region = l$fGeography,
    STab1_1_2 = tmp1,
    STab1_1_3 = tmp2
  )

  # Accounting for the word "County" in report.
  # Also, if an error occurs,
  # please see comment in preprocessing.R about boolean type & icon_Walk.png.
  if(l$fGeography %in% d$regions$County[which(d$regions$True_County==T)]) {
    # add the word County to alt texts.
    rt$alt1[which(rt$icon == "icon_Walk.png")] <- 
      sub("resident", 
          "<b>County</b> resident", 
          rt$alt1[which(rt$icon == "icon_Walk.png")])
    rt$alt2[which(rt$icon == "icon_Walk.png")] <- 
      sub("resident", 
          "<b>County</b> resident", 
          rt$alt2[which(rt$icon == "icon_Walk.png")])
    rt$alt3[which(rt$icon == "icon_Walk.png")] <- 
      sub("resident", 
          "<b>County</b> resident", 
          rt$alt3[which(rt$icon == "icon_Walk.png")])
  }
  
  # increase
  if(tmp2 > tmp1) {
    text <- c(text, rt[row, "alt1"])
    # no change
  } else if(tmp2 == tmp1) {
    text <- c(text, rt[row, "alt2"])
    # decrease
  } else if (tmp2 < tmp1){
    text <- c(text, rt[row, "alt3"])
  }
  
  rm(tmp1, tmp2)
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Row 3 - Physical Activity & Chronic Disease
  row <- 3
  tmp1 <- ceiling(df_list[[4]][1, 3])
  
  # increase
  if(tmp1 > 0) {
    text <- c(text, rt[row, "alt1"])
    
    # no change
  } else if(tmp1 == 0) {
    text <- c(text, rt[row, "alt2"])
    
    # decrease
  } else if (tmp1 < 0){
    text <- c(text, rt[row, "alt3"])
  }
  
  val[[row]] <- list(
    STab4_1_3 = abs(tmp1)
  )
  
  rm(tmp1)
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Row 4 - Air Quality Deaths
  row <- 4
  tmp1 <- ceiling(df_list[[4]][2,3])
  
  # increase
  if(tmp1 > 0) {
    text <- c(text, rt[row, "alt1"])
    
    # no change
  } else if(tmp1 == 0) {
    text <- c(text, rt[row, "alt2"])
    
    # decrease
  } else if (tmp1 < 0){
    text <- c(text, rt[row, "alt3"])
  }
  
  val[[row]] <- list(
    STab4_2_3 = abs(tmp1)
  )
  
  
  rm(tmp1)
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Row 5 - Fatal Injuries
  row <- 5
  tmp1 <- ceiling(l$pop_adjust*
                    (l$rti_RR_mode[6, 7] - l$rti_RR_mode[6, 6]) +
                    (l$rti_RR_mode[1, 7] - l$rti_RR_mode[1, 6]))

  # increase
  if(tmp1 > 0) {
    text <- c(text, rt[row, "alt1"])
    
    # no change
  } else if(tmp1 == 0) {
    text <- c(text, rt[row, "alt2"])
    
    # decrease
  } else if (tmp1 < 0){
    text <- c(text, rt[row, "alt3"])
  }
  
  val[[row]] <- list(
    fatal_ped_bike = abs(tmp1)
  )
  
  rm(tmp1)
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Row 6 - Cost
  row <- 6
  # Note: create two variables, one for mathematical comparison, other
  # for formatting.
  tmp1 <- tmp1_exact <- df_list[[5]][1, 2]
  tmp2 <- tmp2_exact <- df_list[[5]][2, 2]
  
  # assuming accuracy ~$1,000 is not important...
  # at 1,000 make it equal to zero
  if(abs(tmp1) < 0.000001) tmp1 <- 0
  if(abs(tmp2) < 0.000001) tmp2 <- 0
  
  # if greater than or equal to billion
  if(abs(tmp1) >= 1) {
    dollars_unit1 <- "billion"
    tmp1 <- format(1 * tmp1, digits = 1)
  } else {
    dollars_unit1 <- "million"
    tmp1 <- format(1000 * tmp1, digits = 1)
  }
  
  # if greater than or equal to billion
  if(abs(tmp2) >= 1) {
    dollars_unit2 <- "billion"
    tmp2 <- format(1 * tmp2, digits = 1)
  } else {
    dollars_unit2 <- "million"
    tmp2 <- format(1000 * tmp2, digits = 1)
  }
  
  # Now choose which "alt" in report_template.csv to print.
  if (tmp1 == 0 & tmp2 == 0){
    # alt2
    # no change in cost
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    # Here, we're assuming we don't care
    # we're off by the amount to which
    # we've rounded tmp1/tmp2.
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    val[[row]]$STab5_1_a <- tmp1
    val[[row]]$STab5_1_b <- tmp2
    val[[row]]$dollars_unit_a <- dollars_unit1
    val[[row]]$dollars_unit_b <- dollars_unit2
    text <- c(text, rt[row, "alt2"])
    
  } else if (tmp1_exact > 0 & tmp2_exact > 0 |
             tmp1_exact == 0 & tmp2_exact > 0 |
             tmp1_exact > 0 & tmp2_exact == 0) {
    # alt1
    # both values are positive OR one is & other is zero (i.e. benefits)
    val[[row]]$STab5_1_a <- tmp1
    val[[row]]$STab5_1_b <- tmp2
    val[[row]]$dollars_unit_a <- dollars_unit1
    val[[row]]$dollars_unit_b <- dollars_unit2
    text <- c(text, rt[row, "alt1"])
    
  } else if (tmp1_exact < 0 & tmp2_exact < 0 |
             tmp1_exact == 0 & tmp2_exact < 0 |
             tmp1_exact < 0 & tmp2_exact == 0) {
    # alt3
    # both values are negative OR one is & other is zero (i.e. costs)
    # first remove negative signs.
    if(grepl("-",tmp1)) tmp1 <- sub("-", "", tmp1)
    if(grepl("-",tmp2)) tmp2 <- sub("-", "", tmp2)
    
    val[[row]]$STab5_1_a <- tmp1
    val[[row]]$STab5_1_b <- tmp2
    val[[row]]$dollars_unit_a <- dollars_unit1
    val[[row]]$dollars_unit_b <- dollars_unit2
    text <- c(text, rt[row, "alt3"])
    
  } else if (tmp1_exact < 0 & tmp2_exact > 0 |
             tmp1_exact > 0 & tmp2_exact < 0 ) {
    # alt4
    # values do not share a sign, and neither is 0
    val[[row]]$STab5_1_a <- tmp1
    val[[row]]$STab5_1_b <- tmp2
    val[[row]]$dollars_unit_a <- dollars_unit1
    val[[row]]$dollars_unit_b <- dollars_unit2
    text <- c(text, rt[row, "alt4"])
    
  } else {
    # catch all error that simply prints the values side by side.
    text <- c(text, paste("value1:", tmp1a, "value2:", tmp2a))
  }
  
  rm(tmp1, tmp2, tmp1_exact, tmp2_exact)
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Row 7 - Carbon Emissions
  row <- 7
  tmp1 <- ceiling(df_list[[6]][1, 2])
  tmp2 <- ceiling(df_list[[6]][1, 3])
  
  val[[row]]$STab6_1_2 <- tmp1
  val[[row]]$STab6_1_3 <- tmp2
  
  val[[row]]$Scenario <- l$scenario$name
  
  # increase
  if(tmp2 > tmp1) {
    text <- c(text, rt[row, "alt1"])
    # no change
  } else if(tmp2 == tmp1) {
    text <- c(text, rt[row, "alt2"])
    # decrease
 } else if (tmp2 < tmp1){
    text <- c(text, rt[row, "alt3"])
    

#    print(l$scenario$name)
#    print(val[[row]]$Scenario)
#  } else if (val[[row]]$Scenario == "Low Carbon Driving"){
#    text <- c(text, rt[row, "alt4"])    
    
  }
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Row 8 - Read More
  row <- 8
  text <- c(text, rt[row, "alt1"])
  
  val[[row]]$here <- "https://doi.org/10.1016/j.jth.2017.04.011"
  
  l$report_values <- val
  l$report_text <- text
  l$report_icons <- icons
  
  l  # return
}



# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# FUNCTION: Report Maker
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#' Creates the html summary report or infographic.
#' 
#' @param l is a list with report_type, detail
#' @return l with a new list of tags as an element
fn_reporter <- function(l) {
  
  l <- fn_report_calc(l)
  rv <- l$report_values
  rt <- l$report_text
  ri <- l$report_icons
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # intro paragraph(s)
  intros <- tagList(
    tags$p(rt[1]),
    tags$br()
  )
  
  # create table
  tabl <- lapply(seq_along(ri), function(i) {
    if(i==1) return(NULL)  # skip first row.
    txt <- rt[i]
    values <- rv[[i]]
    # Check if replacement necessary
    if(i!=8 & grepl("\\{", txt, perl=T)){
      # Replace values 
      for(j in seq_along(values)){
        nm <- names(values)[j]
        nm2 <- paste0( "\\{",
                       nm,
                       "\\}")
        txt <- gsub(pattern=nm2, 
                    replacement=paste0(
                      "<b>",
                      values[[j]],
                      "</b>"
                    ), 
                    x=txt,
                    perl=T)
      }
    } else if(i==8){
      for(j in seq_along(values)){
        nm <- names(values)[j]
        nm2 <- paste0( "\\{",
                       nm,
                       "\\}")
        txt <- gsub(pattern=nm2, 
                    replacement=paste0(
                      "<a href=\"",
                      values[[j]],
                      "\">here</a>"
                    ), 
                    x=txt,
                    perl=T)
      }
    }
    
    # return
    tags$tr(
      # cell
      tags$td(
        tags$img(
          src = ri[i],
          style = "height:100px;"
        ),
        style = "text-align: center;"
      ),
      # cell
      tags$td(
        style="padding-left: 1em;",
        tags$p(HTML(txt))
      )
    )
  })  # end of sapply
  

  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # create output tagList
  out <- append(intros, 
                list(
                  tags$table(
                    class="ithimToolReport",
                    tags$tbody(tabl)
                  ),
                  tags$br()
                )
  )
  
  
  l$report <- out
  
  l  # return
}


# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# FUNCTION GROUP ----
# The below functions create the infographic
# Primary: 
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# TODO combine fn_ig_DataAssembler with fn_ig_textFormatter

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# FUNCTION: Infographic Data Assembler
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#' Assembles the data for the infographic.
#' 
#' @param l is the output of run()
#' @return l with element "visual"
fn_ig_DataAssembler <- function(l){
  # subset prefab infographic by region
  infographic <- d$infographic[
    which(
      d$infographic$Region==l$fRegion &
        d$infographic$Year==l$fYear
    ),
    ]
  
  # error checking
  if(is.null(infographic)) {
    stop("Error fn_infographer: infographic subset failed.")
  }
  
  # get summary tables
  df_list <- fn_dataframer(l)$df_list
  
  # recycle Neil's code to make the infographic
  infographic$LCDGeo <- infographic$LCD
  infographic[2:4, "LCDGeo"] <-
    infographic[2:4, "LCDpercapita"] * l$cause_sum[2, "Population"]
  infographic$USSGGeo <- infographic$USSG
  infographic[2:4, "USSGGeo"] <-
    infographic[2:4, "USSGpercapita"] * l$cause_sum[2, "Population"]
  
  # Infographic data for selected scenario
  infographic$Scenario <- NA
  infographic[1, "Scenario"] <- l$at_sat_wide[17, "Scenario.Total"]
  infographic[2, "Scenario"] <- ifelse(is.na(l$co2[3, 9]),
                                       l$co2[2, 9],
                                       l$co2[3, 9])
  infographic[3, "Scenario"] <- df_list[[4]][4, 5]
  infographic[4, "Scenario"] <- df_list[[5]][2, 2]
  
  # calculation of delta PM2.5
  # delta_pm_pct <-
  #   -100 * 
  #   (log(l$PM_PAF_InflamHD[4, 6]) / l$PM_PAF_InflamHD[4, 5]) / 
  #   l$PM25_VMT[1, 2]
  
  # calculation of delta PM2.5 emissions equal to delta VMT pct
  pm_tpd_change_pct <- (l$VMT_pct * l$PM25_VMT$PMEmissionTPD) /
    l$PM25_VMT$PMEmissionTPD
  
  infographic[5, "Scenario"] <- pm_tpd_change_pct
  
  if (l$scenario$name %in% c("Low Carbon Driving")) {
#    infographic[,"LCDGeo"] <- infographic[,"Scenario"]
  }
  
  if (l$scenario$name %in% c("U. S. Surgeon General Recommendation")){
    infographic[,"USSGGeo"] <- infographic[,"Scenario"]
  }
  
  # infographic <- paste(infographic$Scenario, collapse=", ")

  # l$visual <- list(tags$p(infographic))
  
  l$visual <- infographic
  # saveRDS(l, "l_sample_infographic")

  l  # return
}

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# FUNCTION: Infographic Text Formatter
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#' Create list of formatted text to be used in the ITHIM infographic. Note, 
#' comparators are used in this function.
#' 
#' @param l is a list with element `visual`
#' `visual` is derived from fn_ig_DataAssembler
#' @return l, list with `ig_list` added.
fn_ig_textFormatter <- function(l){
  # create empty list to fill
  r <- sapply(1:5, function(x) NULL)
  
  h1 <- l$ig_master_fontsize
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Scenario Title ----
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  
  # Create output string for this panel.
  tmp <- list()
  
  # output string - scenario
  tmp$scenario <- paste0(strwrap(
    x = l$scenario$name,
    width = 20,
    simplify = T
  ),
  collapse = "\n")
  
  tmp$scenario_units <- ""
  
  # output string - ussg
  tmp$ussg <- paste0(strwrap(
    x = "US Surgeon General Recommendation",
    width = 20,
    simplify = T
  ),
  collapse = "\n")
  
  tmp$ussg_units <- ""
  
  # output string - lcd
  tmp$lcd <- paste0(strwrap(
    x = "Low Carbon Driving (33.5%)",
    width = 20,
    simplify = T
  ),
  collapse = "\n")
  
  tmp$lcd_units <- ""
  
  # give this row parameters for fn_textGrobber
  r[[1]] <- mapply(function(x, fontsize, vjust, ro, co) {
    list(text = x,
         fontsize=fontsize,
         vjust=vjust,
         ro=ro,
         co=co)
  }, 
  x = tmp, 
  fontsize=rep(c(h1/2, h1/2), 3),
  vjust=rep(c(1,0), 3),
  ro=rep(c(3,4), 3),
  co=c(1,1,2,2,3,3),
  SIMPLIFY=F)
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # GHG Emissions ----
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # comparator - scenario
  if (l$visual$Scenario[2] < 0) {
    comp_scenario <- "Less"
  } else if (l$visual$Scenario[2] > 0) {
    comp_scenario <- "More"
    l$visual$Scenario[2] <- (-1 * l$visual$Scenario[2])
  } else if (l$visual$Scenario[2] == 0) {
    comp_scenario <- ""
  }
  # comparator - ussg
  if (l$visual$USSGGeo[2] < 0) {
    comp_ussg <- "Less"
  } else if (l$visual$USSGGeo[2] > 0) {
    comp_ussg <- "More"
    l$visual$USSGGeo[2] <- (-1 * l$visual$USSGGeo[2])
  } else if (l$visual$USSGGeo[2] == 0) {
    comp_ussg <- ""
  } 
  # comparator - lcd
  if (l$visual$LCDGeo[2] < 0) {
    comp_lcd <- "Less"
  } else if (l$visual$LCDGeo[2] > 0) {
    comp_lcd <- "More"
    l$visual$LCDGeo[2] <- (-1 * l$visual$LCDGeo[2])
  } else if (l$visual$LCDGeo[2] == 0) {
    comp_lcd <- ""
  }
  
  # Create output string for this panel.
  tmp <- list()
  
  # output string - scenario
  tmp$scenario <- paste(format(-1 * l$visual$Scenario[2], 
                               scientific=F, 
                               digits=2, 
                               big.mark = ","),
                        comp_scenario)
  tmp$scenario_units <- "Million Metric Tons"
  
  # output string - ussg
  tmp$ussg <- paste(format(-1 * l$visual$USSGGeo[2], 
                           scientific=F, 
                           digits=2, 
                           big.mark = ","),
                    comp_ussg)
  tmp$ussg_units <- "Million Metric Tons"
  
  # output string - lcd
  tmp$lcd <- paste(format(-1 * l$visual$LCDGeo[2], 
                          scientific=F, 
                          digits=2, 
                          big.mark = ","),
                   comp_lcd)
  tmp$lcd_units <- "Million Metric Tons"
  
  # give this row parameters for fn_textGrobber
  r[[2]] <- mapply(function(x, fontsize, vjust, ro, co) {
    list(text = x,
         fontsize=fontsize,
         vjust=vjust,
         ro=ro,
         co=co)
  }, 
  x = tmp, 
  fontsize=rep(c(h1, h1/2), 3),
  vjust=rep(c(1,0), 3),
  ro=rep(c(2,3), 3),
  co=c(1,1,2,2,3,3),
  SIMPLIFY=F)
  
  rm(comp_scenario, comp_ussg, comp_lcd)
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Years of Life ----
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # comparator - scenario
  if (l$visual$Scenario[3] > 0) {
    comp_scenario <- "Gained"
  } else if (l$visual$Scenario[3] < 0) {
    comp_scenario <- "Lost"
    l$visual$Scenario[3] <- abs(l$visual$Scenario[3])
  }
  # comparator - ussg
  if (l$visual$USSGGeo[3] > 0) {
    comp_ussg <- "Gained"
  } else if (l$visual$USSGGeo[3] < 0) {
    comp_ussg <- "Lost"
    l$visual$USSGGeo[3] <- abs(l$visual$USSGGeo[3])
  }
  # comparator - lcd
  if (l$visual$LCDGeo[3] > 0) {
    comp_lcd <- "Gained"
  } else if (l$visual$LCDGeo[3] < 0) {
    comp_lcd <- "Lost"
    l$visual$LCDGeo[3] <- abs(l$visual$LCDGeo[3])
  }
  
  # Create output string for this panel.
  tmp <- list()
  
  # output string - scenario
  tmp$scenario <- format(l$visual$Scenario[3], 
                         scientific=F, 
                         digits=2, 
                         big.mark = ",")
  tmp$scenario_units <- paste("DALYs*", comp_scenario, "Per Year")
  
  # output string - ussg
  tmp$ussg <- format(l$visual$USSGGeo[3], 
                     scientific=F, 
                     digits=2, 
                     big.mark = ",")
  
  tmp$ussg_units <- paste("DALYs*", comp_ussg, "Per Year")
  
  # output string - lcd
  tmp$lcd <- format(l$visual$LCDGeo[3], 
                    scientific=F, 
                    digits=2, 
                    big.mark = ",")
  
  tmp$lcd_units <- paste("DALYs*", comp_lcd, "Per Year")
  
  # give this row parameters for fn_textGrobber
  r[[3]] <- mapply(function(x, fontsize, vjust, ro, co) {
    list(text = x,
         fontsize=fontsize,
         vjust=vjust,
         ro=ro,
         co=co)
  }, 
  x = tmp, 
  fontsize=rep(c(h1, h1/2), 3),
  vjust=rep(c(1,0), 3),
  ro=rep(c(2,3), 3),
  co=c(1,1,2,2,3,3),
  SIMPLIFY=F)
  
  rm(comp_scenario, comp_ussg, comp_lcd)
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Health Cost Savings ----
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # comparator - scenario
  if (l$visual$Scenario[4] > 0) {
    comp_scenario <- "Gained"
  } else if (l$visual$Scenario[4] < 0) {
    comp_scenario <- "Lost"
    l$visual$Scenario[4] <- abs(l$visual$Scenario[4])
  }
  
  # comparator - ussg
  if (l$visual$USSGGeo[4] > 0) {
    comp_ussg <- "Gained"
  } else if (l$visual$USSGGeo[4] < 0) {
    comp_ussg <- "Lost"
    l$visual$USSGGeo[4] <- abs(l$visual$USSGGeo[4])
  }
  
  # comparator - lcd
  if (l$visual$LCDGeo[4] > 0) {
    comp_lcd <- "Gained"
  } else if (l$visual$LCDGeo[4] < 0) {
    comp_lcd <- "Lost"
    l$visual$LCDGeo[4] <- abs(l$visual$LCDGeo[4])
  }
  
  # see if it should be millions or billions.
  if (
    abs(l$visual$Scenario[4]) < 1 |
    l$visual$USSGGeo[4] < 1 |
    l$visual$LCDGeo[4] < 1
  ) {
    comp2 <- "Millions"
    scenario <- l$visual$Scenario[4] * 1000
    ussg <- l$visual$USSGGeo[4] * 1000
    lcd <- l$visual$LCDGeo[4] * 1000
  } else {
    comp2 <- "Billions"
    scenario <- l$visual$Scenario[4]
    ussg <- l$visual$USSGGeo[4]
    lcd <- l$visual$LCDGeo[4]
  } 
  
  # Create output string for this panel.
  tmp <- list()
  
  # output string - scenario
  tmp$scenario <- paste0("$",
                         format(scenario, 
                                scientific=F, 
                                digits=2, 
                                big.mark = ","))
  tmp$scenario_units <- paste0("(in ", comp2, ") ", comp_scenario)
  
  # output string - ussg
  tmp$ussg <- paste0("$",
                     format(ussg, 
                            scientific=F, 
                            digits=2, 
                            big.mark = ","))
  tmp$ussg_units <- paste0("(in ", comp2, ") ", comp_ussg)
  
  # output string - lcd
  tmp$lcd <- paste0("$",
                    format(lcd, 
                           scientific=F, 
                           digits=2, 
                           big.mark = ","))
  tmp$lcd_units <- paste0("(in ", comp2, ") ", comp_lcd)
  
  # give this row paramters for fn_textGrobber
  r[[4]] <- mapply(function(x, fontsize, vjust, ro, co) {
    list(text = x,
         fontsize=fontsize,
         vjust=vjust,
         ro=ro,
         co=co)
  }, 
  x = tmp,
  fontsize = rep(c(h1, h1 / 2), 3),
  vjust = rep(c(1, 0), 3),
  ro = rep(c(2, 3), 3),
  co = c(1, 1, 2, 2, 3, 3),
  SIMPLIFY = F)
  
  # garbage collection
  rm(scenario, ussg, lcd, comp2, comp_scenario, comp_ussg, comp_lcd)
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Air Pollution ----
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # comparators - scenario
  if (l$visual$Scenario[5] > 0) {
    comp_scenario <- "Lower"
  } else if (l$visual$Scenario[5] < 0) {
    comp_scenario <- "Higher"
    l$visual$Scenario[5] <- abs(l$visual$Scenario[5])
  } else if (l$visual$Scenario[5] == 0) {
    comp_scenario <- ""
  }
  # comparators - ussg
  if (l$visual$USSGGeo[5] > 0) {
    comp_ussg <- "Lower"
  } else if (l$visual$USSGGeo[5] < 0) {
    comp_ussg <- "Higher"
    l$visual$USSGGeo[5] <- abs(l$visual$USSGGeo[5])
  } else if (l$visual$USSGGeo[5] == 0) {
    comp_ussg <- ""
  }
  # comparators - lcd
  if (l$visual$LCDGeo[5] > 0) {
    comp_lcd <- "Lower"
  } else if (l$visual$LCDGeo[5] < 0) {
    comp_lcd <- "Higher"
    l$visual$LCDGeo[5] <- abs(l$visual$LCDGeo[5])
  } else if (l$visual$LCDGeo[5] == 0) {
    comp_lcd <- ""
  }
  
  # Create output string for this panel.
  tmp <- list()
  
  # output string - scenario
  tmp$scenario <- paste0(
    format(l$visual$Scenario[5], 
           scientific=F, 
           digits=2, 
           big.mark = ","),
    "%"
  )
  
  if (comp_scenario != ""){
    tmp$scenario_units <- paste(comp_scenario, "(than baseline)")
  } else {
    tmp$scenario_units <- "(i.e. no change)"
  }
  
  # output string - ussg
  tmp$ussg <- paste0(
    format(l$visual$USSGGeo[5], 
           scientific=F, 
           digits=2, 
           big.mark = ","),
    "%"
  )
  
  if (comp_ussg != ""){
    tmp$ussg_units <- paste(comp_ussg, "(than baseline)")
  } else {
    tmp$ussg_units <- "(i.e. no change)"
  }
  
  # output string - lcd
  tmp$lcd <- paste0(
    format(l$visual$LCDGeo[5], 
           scientific=F, 
           digits=2, 
           big.mark = ","), 
    "%"
  )
  
  if (comp_lcd != ""){
    tmp$lcd_units <- paste(comp_lcd, "(than baseline)")
  } else {
    tmp$lcd_units <- "(i.e. no change)"
  }
  
  # give this row paramters for fn_textGrobber
  r[[5]] <- mapply(function(x, fontsize, vjust, ro, co) {
    list(text = x,
         fontsize=fontsize,
         vjust=vjust,
         ro=ro,
         co=co)
  }, 
  x = tmp, 
  fontsize=rep(c(h1, h1/2), 3),
  vjust=rep(c(1,0), 3),
  ro=rep(c(2,3), 3),
  co=c(1,1,2,2,3,3),
  SIMPLIFY=F)
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # save list to `l`
  l$ig_list <- r
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  l  # return
}

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# FUNCTION: Infographic textGrob Maker
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#' Create a list of textGrobs given some parameters.
#' In essence, supply it with a list in which each (primary/first order) 
#' element represents one text grob. Each primary element should itself 
#' contain four sub elements: text, fontsize, ro and co.
#' Input is 1 element of the output of fn_ig_textFormatter
#'
#' @param text_list is a list of 
#' @return text_list is now a list of grobs (of text).
#' Text font changed to dark blue from CARB green
fn_ig_textGrobber <- function(text_list){
  lapply(text_list, function(x){
    # text_list is a list of x elements
    # x is `text`, `fontsize`, `ro`, and `co`
    textGrob(
      x$text,
      vjust=x$vjust,
      gp = gpar(
        col = "#0C4B6B",
        fontfamily = "Lato",
        fontsize = x$fontsize
      ),
      # end gpar
      vp = viewport(layout.pos.row = x$ro, 
                    layout.pos.col = x$co)
    )
  })  # end lapply
}

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# FUNCTION: Infographic Tripartite Panel Maker
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#' Creates a single grob for the panels (i.e. one component) in the infographic 
#' that each have three columns. Relies on the previous ig functions in this 
#' group.
#' 
#' @param panel_list is a list:
#' 1. single element output of fn_ig_textFormatter
#' 2. panel ID number
#' 3. a single png
#' 4. a vector of viewport ratios
#' @return a single grob (composed of a gTree of rasters & texts)
fn_ig_panelArborist <- function(params){
  num <- params$id # panel ID number
  
  # create list of textGrobs (tg)
  tg <- fn_ig_textGrobber(params$text)

  panel <- gTree(
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    children = gList(
      # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      rasterGrob(
        params$png,
        height = unit(1, "npc"),  # relative to gTree viewport.
        name = paste0("panel_", num, "_background")
      ),
      # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      # LEFT
      # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      tg[[1]],
      tg[[2]],
      # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      # CENTER
      # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      tg[[3]],
      tg[[4]],
      # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      # RIGHT
      # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
      tg[[5]],
      tg[[6]]
    ),  # end of children
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    vp = viewport(
      layout = grid.layout(
        nrow = params$nr,  # How many rows make up this panel?
        ncol = 3,  # How many columns in this panel?
        heights=unit(params$vp_ratios, "null")  # Height ratios for each row?
      ),
      width = unit(resolveRasterSize(rasterGrob(params$png))$width, "in"),
      height = unit(resolveRasterSize(rasterGrob(params$png))$height, "in"),
      name = paste0("panel_", num)
    )  # end of viewport
  )  # end of gTree
  
  panel  # return
}

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# FUNCTION: Infographic Png Maker
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#' Creates a side-effect (of a png). This function combines the efforts of
#' the preceding functions in this group.
#' 
#' @param l is a list
#' @return nothing. It creates a png as a side-effect.
fn_ig_pngMaker <- function(l){

  # obtain data
  l <- fn_ig_DataAssembler(l)
  
  l$ig_master_fontsize <- 100
  
  # Image output settings.
  # png(
  #   # filename="model2.png",
  #   width=dim(d$infographic_pngs[[1]])[2],
  #   height= sum(sapply(d$infographic_pngs, function(x) dim(x)[1])),
  #   unit="px"
  # )
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Create new image
  grid.newpage()
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Design Header Panels
  head_panels <-
    lapply(seq_along(d$infographic_pngs[1:3]), function(i) {
      # TODO, one could just make it lapply(1:4, function(i){...
      rasterGrob(
        image = d$infographic_pngs[[i]],
        # height = unit(1, "npc"),
        # relative to gTree viewport.
        name = paste0("head_", i, "_background"),
        vp = viewport(
          width = unit(resolveRasterSize(rasterGrob(
            d$infographic_pngs[[1]]
          ))$width, "in"),
          height = unit(resolveRasterSize(rasterGrob(
            d$infographic_pngs[[i]]
          ))$height, "in"),
          name = paste0("panel_", i)
        )  # end of viewport
      )
    })
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Design Tripartite Panels
  formatted_text <- fn_ig_textFormatter(l)$ig_list
  
  core_panels <- mapply(
    function(id, png, text, nrows, vpr) {
      fn_ig_panelArborist(list(
        id = id,
        png = png,
        text = text,
        nr = nrows,
        # For grid.layout argument heights for each row in a single whole panel
        vp_ratios = vpr
      ))
    },
    id = seq(4, 8),
    png = d$infographic_pngs[4:8],
    text = formatted_text,
    # num of rows per panel.
    nrows = c(4, rep(3, 4)),  
    # panel row ratios
    vpr = list(
      rep(1, 4),
      rep(1, 3),
      rep(1, 3),
      rep(1, 3),
      rep(1, 3)
      ),
    SIMPLIFY = F
  )
  
  # garbage collection
  rm(formatted_text)
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Design Panel 9
  
  panel9 <- rasterGrob(
    d$infographic_pngs[[9]],
    height = unit(1, "npc"),
    # relative to gTree viewport.
    name = paste0("head_9_background"),
    vp = viewport(
      width = unit(resolveRasterSize(rasterGrob(
        d$infographic_pngs[[1]]
      ))$width, "in"),
      height = unit(resolveRasterSize(rasterGrob(
        d$infographic_pngs[[9]]
      ))$height, "in"),
      name = paste0("panel_9")
    )  # end of viewport
  )
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Design Footnote
  footnotes <- gTree(
    children=gList(
      rasterGrob(d$infographic_pngs[[10]],
                 height = unit(1, "npc"),  # relative to gTree viewport.
                 name = paste0("footnotes_background")
      ),
      textGrob(
        label = "Note: \"DALY\" is Disability Adjusted Life Years",
        vjust=1,
        gp = gpar(
          col = "black",
          fontfamily = "Lato",
          fontsize = l$ig_master_fontsize/4
        ),
        # end gpar
        vp = viewport(layout.pos.row = 2, 
                      layout.pos.col = 1)
      ),
      textGrob(
        label = "Created by ITHIM California. Designed by Amy Weiher (2019).",
        vjust=1,
        gp = gpar(
          col = "black",
          fontfamily = "Lato",
          fontsize = l$ig_master_fontsize/2
        ),
        # end gpar
        vp = viewport(layout.pos.row = 3, 
                      layout.pos.col = 1)
      )
    ),
    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    vp = viewport(
      layout = grid.layout(
        nrow = 4,
        ncol = 1,
        heights=unit(rep(1,4), "null")
      ),
      width = unit(
        resolveRasterSize(rasterGrob(d$infographic_pngs[[1]]))$width, "in"),
      height = unit(
        resolveRasterSize(rasterGrob(d$infographic_pngs[[10]]))$height, "in"),
      name = paste0("panel_footnotes")
    )  # end of viewport
  )
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Design frame layout
  layout <- grid.layout(
    nrow = length(d$infographic_pngs),
    ncol = 1,
    widths = unit(1, "null"),  # resize to max space.
    heights = unit(
      sapply(
        d$infographic_pngs, function(x){
          resolveRasterSize(rasterGrob(x))$height
        })
      , "in")
  )
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Fill out Frame
  root <- frameGrob(layout = layout,
                    vp = viewport(
                      width = unit(resolveRasterSize(rasterGrob(
                        d$infographic_pngs[[1]]
                      ))$width, "in"),
                      height = unit(sum(sapply(d$infographic_pngs, function(x) {
                        resolveRasterSize(rasterGrob(x))$height
                      })), "in")
                    ))
  
  for(i in seq_along(head_panels)){
    root <- placeGrob(root,
                      head_panels[[i]],
                      row=i)
  }
  rm(i)  # gc
  
  for(i in seq_along(core_panels)){
    root <- placeGrob(root,
                      core_panels[[i]],
                      row=i+3)
  }
  rm(i)  # gc
  
  root <- placeGrob(root,
                    panel9,
                    row=9
  )
  
  root <- placeGrob(root,
                    footnotes,
                    row=10
  )
  
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  grid.draw(root)  # side effect
  # dev.off()
}